@@ -296,17 +296,6 @@ adw_demo_page_animations_set_property (GObject      *object,
   }
 }
 
-static void
-adw_demo_page_animations_dispose (GObject *object)
-{
-  AdwDemoPageAnimations *self = ADW_DEMO_PAGE_ANIMATIONS (object);
-
-  g_clear_object (&self->timed_animation);
-  g_clear_object (&self->spring_animation);
-
-  G_OBJECT_CLASS (adw_demo_page_animations_parent_class)->dispose (object);
-}
-
 static void
 adw_demo_page_animations_class_init (AdwDemoPageAnimationsClass *klass)
 {
@@ -315,21 +304,16 @@ adw_demo_page_animations_class_init (AdwDemoPageAnimationsClass *klass)
 
   object_class->set_property = adw_demo_page_animations_set_property;
   object_class->get_property = adw_demo_page_animations_get_property;
-  object_class->dispose = adw_demo_page_animations_dispose;
 
   props[PROP_TIMED_ANIMATION] =
-    g_param_spec_object ("timed-animation",
-                         "Timed animation",
-                         "Timed animation",
+    g_param_spec_object ("timed-animation", NULL, NULL,
                          ADW_TYPE_ANIMATION,
-                         G_PARAM_READWRITE);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   props[PROP_SPRING_ANIMATION] =
-    g_param_spec_object ("spring-animation",
-                         "Spring animation",
-                         "Spring animation",
+    g_param_spec_object ("spring-animation", NULL, NULL,
                          ADW_TYPE_ANIMATION,
-                         G_PARAM_READWRITE);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
