@@ -79,9 +79,9 @@ static GtkBuildableIface *parent_buildable_iface;
 
 enum {
   PROP_0,
+  PROP_SUBTITLE,
   PROP_ICON_NAME,
   PROP_ACTIVATABLE_WIDGET,
-  PROP_SUBTITLE,
   PROP_TITLE_LINES,
   PROP_SUBTITLE_LINES,
   LAST_PROP,
@@ -139,15 +139,15 @@ adw_action_row_get_property (GObject    *object,
   AdwActionRow *self = ADW_ACTION_ROW (object);
 
   switch (prop_id) {
+  case PROP_SUBTITLE:
+    g_value_set_string (value, adw_action_row_get_subtitle (self));
+    break;
   case PROP_ICON_NAME:
     g_value_set_string (value, adw_action_row_get_icon_name (self));
     break;
   case PROP_ACTIVATABLE_WIDGET:
     g_value_set_object (value, (GObject *) adw_action_row_get_activatable_widget (self));
     break;
-  case PROP_SUBTITLE:
-    g_value_set_string (value, adw_action_row_get_subtitle (self));
-    break;
   case PROP_SUBTITLE_LINES:
     g_value_set_int (value, adw_action_row_get_subtitle_lines (self));
     break;
@@ -168,15 +168,15 @@ adw_action_row_set_property (GObject      *object,
   AdwActionRow *self = ADW_ACTION_ROW (object);
 
   switch (prop_id) {
+  case PROP_SUBTITLE:
+    adw_action_row_set_subtitle (self, g_value_get_string (value));
+    break;
   case PROP_ICON_NAME:
     adw_action_row_set_icon_name (self, g_value_get_string (value));
     break;
   case PROP_ACTIVATABLE_WIDGET:
     adw_action_row_set_activatable_widget (self, (GtkWidget*) g_value_get_object (value));
     break;
-  case PROP_SUBTITLE:
-    adw_action_row_set_subtitle (self, g_value_get_string (value));
-    break;
   case PROP_SUBTITLE_LINES:
     adw_action_row_set_subtitle_lines (self, g_value_get_int (value));
     break;
@@ -227,6 +227,21 @@ adw_action_row_class_init (AdwActionRowClass *klass)
 
   klass->activate = adw_action_row_activate_real;
 
+  /**
+   * AdwActionRow:subtitle: (attributes org.gtk.Property.get=adw_action_row_get_subtitle org.gtk.Property.set=adw_action_row_set_subtitle)
+   *
+   * The subtitle for this row.
+   *
+   * The subtitle is interpreted as Pango markup unless
+   * [property@PreferencesRow:use-markup] is set to `FALSE`.
+   *
+   * Since: 1.0
+   */
+  props[PROP_SUBTITLE] =
+    g_param_spec_string ("subtitle", NULL, NULL,
+                         "",
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * AdwActionRow:icon-name: (attributes org.gtk.Property.get=adw_action_row_get_icon_name org.gtk.Property.set=adw_action_row_set_icon_name)
    *
@@ -235,9 +250,7 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * Since: 1.0
    */
   props[PROP_ICON_NAME] =
-    g_param_spec_string ("icon-name",
-                         "Icon name",
-                         "The icon name for this row",
+    g_param_spec_string ("icon-name", NULL, NULL,
                          "",
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -257,24 +270,8 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * Since: 1.0
    */
   props[PROP_ACTIVATABLE_WIDGET] =
-      g_param_spec_object ("activatable-widget",
-                           "Activatable widget",
-                           "The widget to be activated when the row is activated",
-                           GTK_TYPE_WIDGET,
-                           G_PARAM_READWRITE);
-
-  /**
-   * AdwActionRow:subtitle: (attributes org.gtk.Property.get=adw_action_row_get_subtitle org.gtk.Property.set=adw_action_row_set_subtitle)
-   *
-   * The subtitle for this row.
-   *
-   * Since: 1.0
-   */
-  props[PROP_SUBTITLE] =
-    g_param_spec_string ("subtitle",
-                         "Subtitle",
-                         "The subtitle for this row",
-                         "",
+    g_param_spec_object ("activatable-widget", NULL, NULL,
+                         GTK_TYPE_WIDGET,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
@@ -287,12 +284,10 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * Since: 1.0
    */
   props[PROP_TITLE_LINES] =
-    g_param_spec_int ("title-lines",
-                      "Number of title lines",
-                      "The desired number of title lines",
+    g_param_spec_int ("title-lines", NULL, NULL,
                       0, G_MAXINT,
                       0,
-                      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwActionRow:subtitle-lines: (attributes org.gtk.Property.get=adw_action_row_get_subtitle_lines org.gtk.Property.set=adw_action_row_set_subtitle_lines)
@@ -305,12 +300,10 @@ adw_action_row_class_init (AdwActionRowClass *klass)
    * Since: 1.0
    */
   props[PROP_SUBTITLE_LINES] =
-    g_param_spec_int ("subtitle-lines",
-                      "Number of subtitle lines",
-                      "The desired number of subtitle lines",
+    g_param_spec_int ("subtitle-lines", NULL, NULL,
                       0, G_MAXINT,
                       0,
-                      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -348,7 +341,6 @@ adw_action_row_init (AdwActionRow *self)
   gtk_widget_init_template (GTK_WIDGET (self));
 
   g_signal_connect (self, "notify::parent", G_CALLBACK (parent_cb), NULL);
-
 }
 
 static void
@@ -394,6 +386,86 @@ adw_action_row_new (void)
   return g_object_new (ADW_TYPE_ACTION_ROW, NULL);
 }
 
+/**
+ * adw_action_row_add_prefix:
+ * @self: an action row
+ * @widget: a widget
+ *
+ * Adds a prefix widget to @self.
+ *
+ * Since: 1.0
+ */
+void
+adw_action_row_add_prefix (AdwActionRow *self,
+                           GtkWidget    *widget)
+{
+  AdwActionRowPrivate *priv;
+
+  g_return_if_fail (ADW_IS_ACTION_ROW (self));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  priv = adw_action_row_get_instance_private (self);
+
+  gtk_box_prepend (priv->prefixes, widget);
+  gtk_widget_show (GTK_WIDGET (priv->prefixes));
+}
+
+/**
+ * adw_action_row_add_suffix:
+ * @self: an action row
+ * @widget: a widget
+ *
+ * Adds a suffix widget to @self.
+ *
+ * Since: 1.0
+ */
+void
+adw_action_row_add_suffix (AdwActionRow *self,
+                           GtkWidget    *widget)
+{
+  AdwActionRowPrivate *priv;
+
+  g_return_if_fail (ADW_IS_ACTION_ROW (self));
+  g_return_if_fail (GTK_IS_WIDGET (widget));
+
+  priv = adw_action_row_get_instance_private (self);
+
+  gtk_box_append (priv->suffixes, widget);
+  gtk_widget_show (GTK_WIDGET (priv->suffixes));
+}
+
+/**
+ * adw_action_row_remove:
+ * @self: an action row
+ * @widget: the child to be removed
+ *
+ * Removes a child from @self.
+ *
+ * Since: 1.0
+ */
+void
+adw_action_row_remove (AdwActionRow *self,
+                       GtkWidget    *child)
+{
+  AdwActionRowPrivate *priv;
+  GtkWidget *parent;
+
+  g_return_if_fail (ADW_IS_ACTION_ROW (self));
+  g_return_if_fail (GTK_IS_WIDGET (child));
+
+  priv = adw_action_row_get_instance_private (self);
+
+  parent = gtk_widget_get_parent (child);
+
+  if (parent == GTK_WIDGET (priv->prefixes) || parent == GTK_WIDGET (priv->suffixes)) {
+    gtk_box_remove (GTK_BOX (parent), child);
+    gtk_widget_set_visible (parent, gtk_widget_get_first_child (parent) != NULL);
+  }
+  else {
+    ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, child);
+  }
+}
+
 /**
  * adw_action_row_get_subtitle: (attributes org.gtk.Method.get_property=subtitle)
  * @self: an action row
@@ -423,6 +495,9 @@ adw_action_row_get_subtitle (AdwActionRow *self)
  *
  * Sets the subtitle for @self.
  *
+ * The subtitle is interpreted as Pango markup unless
+ * [property@PreferencesRow:use-markup] is set to `FALSE`.
+ *
  * Since: 1.0
  */
 void
@@ -536,6 +611,13 @@ activatable_widget_weak_notify (gpointer  data,
  *
  * Sets the widget to activate when @self is activated.
  *
+ * The row can be activated either by clicking on it, calling
+ * [method@ActionRow.activate], or via mnemonics in the title or the subtitle.
+ * See the [property@PreferencesRow:use-underline] property to enable mnemonics.
+ *
+ * The target widget will be activated by emitting the
+ * [signal@Gtk.Widget::mnemonic-activate] signal on it.
+ *
  * Since: 1.0
  */
 void
@@ -554,10 +636,16 @@ adw_action_row_set_activatable_widget (AdwActionRow *self,
 
   g_clear_pointer (&priv->activatable_binding, g_binding_unbind);
 
-  if (priv->activatable_widget)
+  if (priv->activatable_widget) {
+    gtk_accessible_reset_relation (GTK_ACCESSIBLE (priv->activatable_widget),
+                                   GTK_ACCESSIBLE_RELATION_LABELLED_BY);
+    gtk_accessible_reset_relation (GTK_ACCESSIBLE (priv->activatable_widget),
+                                   GTK_ACCESSIBLE_RELATION_DESCRIBED_BY);
+
     g_object_weak_unref (G_OBJECT (priv->activatable_widget),
                          activatable_widget_weak_notify,
                          self);
+  }
 
   priv->activatable_widget = widget;
 
@@ -570,6 +658,11 @@ adw_action_row_set_activatable_widget (AdwActionRow *self,
       g_object_bind_property (widget, "sensitive",
                               self, "activatable",
                               G_BINDING_SYNC_CREATE);
+
+    gtk_accessible_update_relation (GTK_ACCESSIBLE (priv->activatable_widget),
+                                    GTK_ACCESSIBLE_RELATION_LABELLED_BY, priv->title, NULL,
+                                    GTK_ACCESSIBLE_RELATION_DESCRIBED_BY, priv->subtitle, NULL,
+                                    -1);
   }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ACTIVATABLE_WIDGET]);
@@ -582,8 +675,6 @@ adw_action_row_set_activatable_widget (AdwActionRow *self,
  * Gets the number of lines at the end of which the title label will be
  * ellipsized.
  *
- * If the value is 0, the number of lines won't be limited.
- *
  * Returns: the number of lines at the end of which the title label will be
  *   ellipsized
  *
@@ -642,8 +733,6 @@ adw_action_row_set_title_lines (AdwActionRow *self,
  * Gets the number of lines at the end of which the subtitle label will be
  * ellipsized.
  *
- * If the value is 0, the number of lines won't be limited.
- *
  * Returns: the number of lines at the end of which the subtitle label will be
  *   ellipsized
  *
@@ -695,85 +784,6 @@ adw_action_row_set_subtitle_lines (AdwActionRow *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SUBTITLE_LINES]);
 }
 
-/**
- * adw_action_row_add_prefix:
- * @self: an action row
- * @widget: a widget
- *
- * Adds a prefix widget to @self.
- *
- * Since: 1.0
- */
-void
-adw_action_row_add_prefix (AdwActionRow *self,
-                           GtkWidget    *widget)
-{
-  AdwActionRowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_ACTION_ROW (self));
-  g_return_if_fail (GTK_IS_WIDGET (widget));
-
-  priv = adw_action_row_get_instance_private (self);
-
-  gtk_box_prepend (priv->prefixes, widget);
-  gtk_widget_show (GTK_WIDGET (priv->prefixes));
-}
-
-/**
- * adw_action_row_add_suffix:
- * @self: an action row
- * @widget: a widget
- *
- * Adds a suffix widget to @self.
- *
- * Since: 1.0
- */
-void
-adw_action_row_add_suffix (AdwActionRow *self,
-                           GtkWidget    *widget)
-{
-  AdwActionRowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_ACTION_ROW (self));
-  g_return_if_fail (GTK_IS_WIDGET (widget));
-
-  priv = adw_action_row_get_instance_private (self);
-
-  gtk_box_append (priv->suffixes, widget);
-  gtk_widget_show (GTK_WIDGET (priv->suffixes));
-}
-
-/**
- * adw_action_row_remove:
- * @self: an action row
- * @widget: the child to be removed
- *
- * Removes a child from @self.
- *
- * Since: 1.0
- */
-void
-adw_action_row_remove (AdwActionRow *self,
-                       GtkWidget    *child)
-{
-  AdwActionRowPrivate *priv;
-  GtkWidget *parent;
-
-  g_return_if_fail (ADW_IS_ACTION_ROW (self));
-  g_return_if_fail (GTK_IS_WIDGET (child));
-
-  priv = adw_action_row_get_instance_private (self);
-
-  parent = gtk_widget_get_parent (child);
-
-  if (parent == GTK_WIDGET (priv->prefixes))
-    gtk_box_remove (priv->prefixes, child);
-  else if (parent == GTK_WIDGET (priv->suffixes))
-    gtk_box_remove (priv->suffixes, child);
-  else
-    ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, child);
-}
-
 /**
  * adw_action_row_activate:
  * @self: an action row
