@@ -101,9 +101,9 @@ G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (AdwAnimation, adw_animation, G_TYPE_OBJECT)
 
 enum {
   PROP_0,
-  PROP_VALUE,
   PROP_WIDGET,
   PROP_TARGET,
+  PROP_VALUE,
   PROP_STATE,
   LAST_PROP,
 };
@@ -284,10 +284,6 @@ adw_animation_get_property (GObject    *object,
   AdwAnimation *self = ADW_ANIMATION (object);
 
   switch (prop_id) {
-  case PROP_VALUE:
-    g_value_set_double (value, adw_animation_get_value (self));
-    break;
-
   case PROP_WIDGET:
     g_value_set_object (value, adw_animation_get_widget (self));
     break;
@@ -296,6 +292,10 @@ adw_animation_get_property (GObject    *object,
     g_value_set_object (value, adw_animation_get_target (self));
     break;
 
+  case PROP_VALUE:
+    g_value_set_double (value, adw_animation_get_value (self));
+    break;
+
   case PROP_STATE:
     g_value_set_enum (value, adw_animation_get_state (self));
     break;
@@ -312,7 +312,6 @@ adw_animation_set_property (GObject      *object,
                             GParamSpec   *pspec)
 {
   AdwAnimation *self = ADW_ANIMATION (object);
-  AdwAnimationPrivate *priv = adw_animation_get_instance_private (self);
 
   switch (prop_id) {
   case PROP_WIDGET:
@@ -320,7 +319,7 @@ adw_animation_set_property (GObject      *object,
     break;
 
   case PROP_TARGET:
-    g_set_object (&priv->target, g_value_get_object (value));
+    adw_animation_set_target (ADW_ANIMATION (self), g_value_get_object (value));
     break;
 
   default:
@@ -341,22 +340,6 @@ adw_animation_class_init (AdwAnimationClass *klass)
   klass->estimate_duration = adw_animation_estimate_duration;
   klass->calculate_value = adw_animation_calculate_value;
 
-  /**
-   * AdwAnimation:value: (attributes org.gtk.Property.get=adw_animation_get_value)
-   *
-   * The current value of the animation.
-   *
-   * Since: 1.0
-   */
-  props[PROP_VALUE] =
-    g_param_spec_double ("value",
-                         "Value",
-                         "The current value of the animation",
-                         -G_MAXDOUBLE,
-                         G_MAXDOUBLE,
-                         0,
-                         G_PARAM_READABLE);
-
   /**
    * AdwAnimation:widget: (attributes org.gtk.Property.get=adw_animation_get_widget)
    *
@@ -372,25 +355,35 @@ adw_animation_class_init (AdwAnimationClass *klass)
    * Since: 1.0
    */
   props[PROP_WIDGET] =
-    g_param_spec_object ("widget",
-                         "Widget",
-                         "The animation widget",
+    g_param_spec_object ("widget", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwAnimation:target: (attributes org.gtk.Property.get=adw_animation_get_target)
+   * AdwAnimation:target: (attributes org.gtk.Property.get=adw_animation_get_target org.gtk.Property.set=adw_animation_set_target)
    *
    * The target to animate.
    *
    * Since: 1.0
    */
   props[PROP_TARGET] =
-    g_param_spec_object ("target",
-                         "Target",
-                         "The target to animate",
+    g_param_spec_object ("target", NULL, NULL,
                          ADW_TYPE_ANIMATION_TARGET,
-                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
+  /**
+   * AdwAnimation:value: (attributes org.gtk.Property.get=adw_animation_get_value)
+   *
+   * The current value of the animation.
+   *
+   * Since: 1.0
+   */
+  props[PROP_VALUE] =
+    g_param_spec_double ("value", NULL, NULL,
+                         -G_MAXDOUBLE,
+                         G_MAXDOUBLE,
+                         0,
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwAnimation:state: (attributes org.gtk.Property.get=adw_animation_get_state)
@@ -403,12 +396,10 @@ adw_animation_class_init (AdwAnimationClass *klass)
    * Since: 1.0
    */
   props[PROP_STATE] =
-    g_param_spec_enum ("state",
-                       "State",
-                       "The animation state",
+    g_param_spec_enum ("state", NULL, NULL,
                        ADW_TYPE_ANIMATION_STATE,
                        ADW_ANIMATION_IDLE,
-                       G_PARAM_READABLE);
+                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -444,6 +435,13 @@ adw_animation_init (AdwAnimation *self)
  *
  * Gets the widget @self was created for.
  *
+ * It provides the frame clock for the animation. It's not strictly necessary
+ * for this widget to be same as the one being animated.
+ *
+ * The widget must be mapped in order for the animation to work. If it's not
+ * mapped, or if it gets unmapped during an ongoing animation, the animation
+ * will be automatically skipped.
+ *
  * Returns: (transfer none): the animation widget
  *
  * Since: 1.0
@@ -482,6 +480,34 @@ adw_animation_get_target (AdwAnimation *self)
   return priv->target;
 }
 
+/**
+ * adw_animation_set_target: (attributes org.gtk.Method.set_property=target)
+ * @self: an animation
+ * @target: an animation target
+ *
+ * Sets the target @self animates to @target.
+ *
+ * Since: 1.0
+ */
+void
+adw_animation_set_target (AdwAnimation       *self,
+                          AdwAnimationTarget *target)
+{
+  AdwAnimationPrivate *priv;
+
+  g_return_if_fail (ADW_IS_ANIMATION (self));
+  g_return_if_fail (ADW_IS_ANIMATION_TARGET (target));
+
+  priv = adw_animation_get_instance_private (self);
+
+  if (target == priv->target)
+    return;
+
+  g_set_object (&priv->target, target);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TARGET]);
+}
+
 /**
  * adw_animation_get_value: (attributes org.gtk.Method.get_property=value)
  * @self: an animation
