@@ -235,11 +235,9 @@ adw_application_class_init (AdwApplicationClass *klass)
    * Since: 1.0
    */
   props[PROP_STYLE_MANAGER] =
-    g_param_spec_object ("style-manager",
-                         "Style Manager",
-                         "The default style manager",
+    g_param_spec_object ("style-manager", NULL, NULL,
                          ADW_TYPE_STYLE_MANAGER,
-                         G_PARAM_READABLE);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 }
@@ -282,6 +280,9 @@ adw_application_new (const char        *application_id,
  *
  * Gets the style manager for @self.
  *
+ * This is a convenience property allowing to access `AdwStyleManager` through
+ * property bindings or expressions.
+ *
  * Returns: (transfer none): the style manager
  *
  * Since: 1.0
