@@ -213,6 +213,24 @@ update_font_size (AdwAvatar *self)
   pango_attr_list_unref (attributes);
 }
 
+static void
+update_custom_image_snapshot (AdwAvatar *self)
+{
+  GtkSnapshot *snapshot = gtk_snapshot_new ();
+  GdkPaintable *square_image;
+  int height = gdk_paintable_get_intrinsic_height (self->custom_image_source);
+  int width = gdk_paintable_get_intrinsic_width (self->custom_image_source);
+  int size = MIN (width, height);
+
+  gtk_snapshot_translate (snapshot, &GRAPHENE_POINT_INIT ((size - width) / 2.f, (size - height) / 2.f));
+  gdk_paintable_snapshot (self->custom_image_source, snapshot, width, height);
+
+  square_image = gtk_snapshot_free_to_paintable (snapshot, &GRAPHENE_SIZE_INIT (size, size));
+  gtk_image_set_from_paintable (self->custom_image, square_image);
+
+  g_object_unref (square_image);
+}
+
 static void
 adw_avatar_get_property (GObject    *object,
                          guint       property_id,
@@ -330,11 +348,9 @@ adw_avatar_class_init (AdwAvatarClass *klass)
    * Since: 1.0
    */
   props[PROP_ICON_NAME] =
-    g_param_spec_string ("icon-name",
-                         "Icon name",
-                         "The name of an icon to use as a fallback",
+    g_param_spec_string ("icon-name", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwAvatar:text: (attributes org.gtk.Property.get=adw_avatar_get_text org.gtk.Property.set=adw_avatar_set_text)
@@ -347,11 +363,9 @@ adw_avatar_class_init (AdwAvatarClass *klass)
    * Since: 1.0
    */
   props[PROP_TEXT] =
-    g_param_spec_string ("text",
-                         "Text",
-                         "The text used to generate the color and the initials",
+    g_param_spec_string ("text", NULL, NULL,
                          "",
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwAvatar:show-initials: (attributes org.gtk.Property.get=adw_avatar_get_show_initials org.gtk.Property.set=adw_avatar_set_show_initials)
@@ -363,25 +377,23 @@ adw_avatar_class_init (AdwAvatarClass *klass)
    * Since: 1.0
    */
   props[PROP_SHOW_INITIALS] =
-    g_param_spec_boolean ("show-initials",
-                          "Show initials",
-                          "Whether initials are used instead of an icon on the fallback avatar",
+    g_param_spec_boolean ("show-initials", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwAvatar:custom-image: (attributes org.gtk.Property.get=adw_avatar_get_custom_image org.gtk.Property.set=adw_avatar_set_custom_image)
    *
-   * A custom image to use instead of initials or icon.
+   * A custom image paintable.
+   *
+   * Custom image is displayed instead of initials or icon.
    *
    * Since: 1.0
    */
   props[PROP_CUSTOM_IMAGE] =
-    g_param_spec_object ("custom-image",
-                         "Custom image",
-                         "A custom image to use instead of initials or icon",
+    g_param_spec_object ("custom-image", NULL, NULL,
                          GDK_TYPE_PAINTABLE,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwAvatar:size: (attributes org.gtk.Property.get=adw_avatar_get_size org.gtk.Property.set=adw_avatar_set_size)
@@ -391,11 +403,9 @@ adw_avatar_class_init (AdwAvatarClass *klass)
    * Since: 1.0
    */
   props[PROP_SIZE] =
-    g_param_spec_int ("size",
-                      "Size",
-                      "The size of the avatar",
+    g_param_spec_int ("size", NULL, NULL,
                       -1, INT_MAX, -1,
-                      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
@@ -528,6 +538,9 @@ adw_avatar_get_text (AdwAvatar *self)
  *
  * Sets the text used to generate the fallback initials and color.
  *
+ * It's only used to generate the color if [property@Avatar:show-initials] is
+ * `FALSE`.
+ *
  * Since: 1.0
  */
 void
@@ -576,6 +589,8 @@ adw_avatar_get_show_initials (AdwAvatar *self)
  *
  * Sets whether to use initials instead of an icon on the fallback avatar.
  *
+ * See [property@Avatar:icon-name] for how to change the fallback icon.
+ *
  * Since: 1.0
  */
 void
@@ -621,6 +636,8 @@ adw_avatar_get_custom_image (AdwAvatar *self)
  *
  * Sets the custom image paintable.
  *
+ * Custom image is displayed instead of initials or icon.
+ *
  * Since: 1.0
  */
 void
@@ -633,6 +650,11 @@ adw_avatar_set_custom_image (AdwAvatar    *self,
   if (self->custom_image_source == custom_image)
     return;
 
+  if (self->custom_image_source) {
+    g_signal_handlers_disconnect_by_func (self->custom_image_source,
+                                          update_custom_image_snapshot, self);
+  }
+
   g_set_object (&self->custom_image_source, custom_image);
 
   if (custom_image) {
@@ -642,17 +664,10 @@ adw_avatar_set_custom_image (AdwAvatar    *self,
     if (height == width) {
       gtk_image_set_from_paintable (self->custom_image, custom_image);
     } else {
-      GtkSnapshot *snapshot = gtk_snapshot_new ();
-      GdkPaintable *square_image;
-      int size = MIN (width, height);
-
-      gtk_snapshot_translate (snapshot, &GRAPHENE_POINT_INIT ((size - width) / 2.f, (size - height) / 2.f));
-      gdk_paintable_snapshot (custom_image, snapshot, width, height);
-
-      square_image = gtk_snapshot_free_to_paintable (snapshot, &GRAPHENE_SIZE_INIT (size, size));
-      gtk_image_set_from_paintable (self->custom_image, square_image);
-
-      g_object_unref (square_image);
+      update_custom_image_snapshot (self);
+      g_signal_connect_swapped (custom_image, "invalidate-contents",
+                                G_CALLBACK (update_custom_image_snapshot),
+                                self);
     }
 
     gtk_widget_add_css_class (self->gizmo, "image");
@@ -743,14 +758,20 @@ adw_avatar_draw_to_texture (AdwAvatar *self,
   GtkNative *native;
   GskRenderer *renderer;
   int size;
+  graphene_matrix_t transform;
 
   g_return_val_if_fail (ADW_IS_AVATAR (self), NULL);
   g_return_val_if_fail (scale_factor > 0, NULL);
 
   size = self->size * scale_factor;
 
+  g_assert (gtk_widget_compute_transform (GTK_WIDGET (self),
+                                          self->gizmo,
+                                          &transform));
+
   snapshot = gtk_snapshot_new ();
   gtk_snapshot_scale (snapshot, scale_factor, scale_factor);
+  gtk_snapshot_transform_matrix (snapshot, &transform);
   GTK_WIDGET_GET_CLASS (self)->snapshot (GTK_WIDGET (self), snapshot);
 
   node = gtk_snapshot_free_to_node (snapshot);
