@@ -354,11 +354,9 @@ adw_carousel_indicator_dots_class_init (AdwCarouselIndicatorDotsClass *klass)
    * Since: 1.0
    */
   props[PROP_CAROUSEL] =
-    g_param_spec_object ("carousel",
-                         "Carousel",
-                         "The displayed carousel",
+    g_param_spec_object ("carousel", NULL, NULL,
                          ADW_TYPE_CAROUSEL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_override_property (object_class,
                                     PROP_ORIENTATION,
