@@ -656,6 +656,9 @@ adw_carousel_size_allocate (GtkWidget *widget,
                                          child_info->snap_point);
   }
 
+  if (!gtk_widget_get_realized (GTK_WIDGET (self)))
+    return;
+
   x = 0;
   y = 0;
 
@@ -888,13 +891,11 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_N_PAGES] =
-    g_param_spec_uint ("n-pages",
-                       "Number of pages",
-                       "Number of pages",
+    g_param_spec_uint ("n-pages", NULL, NULL,
                        0,
                        G_MAXUINT,
                        0,
-                       G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwCarousel:position: (attributes org.gtk.Property.get=adw_carousel_get_position)
@@ -906,30 +907,26 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_POSITION] =
-    g_param_spec_double ("position",
-                         "Position",
-                         "Current scrolling position",
+    g_param_spec_double ("position", NULL, NULL,
                          0,
                          G_MAXDOUBLE,
                          0,
-                         G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwCarousel:interactive: (attributes org.gtk.Property.get=adw_carousel_get_interactive org.gtk.Property.set=adw_carousel_set_interactive)
    *
    * Whether the carousel can be navigated.
    *
-   * This can be used to temporarily disable a `AdwCarousel` to only allow
+   * This can be used to temporarily disable the carousel to only allow
    * navigating it in a certain state.
    *
    * Since: 1.0
    */
   props[PROP_INTERACTIVE] =
-    g_param_spec_boolean ("interactive",
-                          "Interactive",
-                          "Whether the widget can be swiped",
+    g_param_spec_boolean ("interactive", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwCarousel:spacing: (attributes org.gtk.Property.get=adw_carousel_get_spacing org.gtk.Property.set=adw_carousel_set_spacing)
@@ -939,13 +936,11 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_SPACING] =
-    g_param_spec_uint ("spacing",
-                       "Spacing",
-                       "Spacing between pages",
+    g_param_spec_uint ("spacing", NULL, NULL,
                        0,
                        G_MAXUINT,
                        0,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwCarousel:scroll-params: (attributes org.gtk.Property.get=adw_carousel_get_scroll_params org.gtk.Property.set=adw_carousel_set_scroll_params)
@@ -961,11 +956,9 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_SCROLL_PARAMS] =
-    g_param_spec_boxed ("scroll-params",
-                        "Scroll Parameters",
-                        "Scroll animation spring parameters",
+    g_param_spec_boxed ("scroll-params", NULL, NULL,
                         ADW_TYPE_SPRING_PARAMS,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwCarousel:allow-mouse-drag: (attributes org.gtk.Property.get=adw_carousel_get_allow_mouse_drag org.gtk.Property.set=adw_carousel_set_allow_mouse_drag)
@@ -977,11 +970,9 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_ALLOW_MOUSE_DRAG] =
-    g_param_spec_boolean ("allow-mouse-drag",
-                          "Allow mouse drag",
-                          "Whether to allow dragging with mouse pointer",
+    g_param_spec_boolean ("allow-mouse-drag", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwCarousel:allow-scroll-wheel: (attributes org.gtk.Property.get=adw_carousel_get_allow_scroll_wheel org.gtk.Property.set=adw_carousel_set_allow_scroll_wheel)
@@ -993,11 +984,9 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_ALLOW_SCROLL_WHEEL] =
-    g_param_spec_boolean ("allow-scroll-wheel",
-                          "Allow scroll wheel",
-                          "Whether the widget will respond to scroll wheel events",
+    g_param_spec_boolean ("allow-scroll-wheel", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwCarousel:allow-long-swipes: (attributes org.gtk.Property.get=adw_carousel_get_allow_long_swipes org.gtk.Property.set=adw_carousel_set_allow_long_swipes)
@@ -1009,27 +998,25 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Since: 1.0
    */
   props[PROP_ALLOW_LONG_SWIPES] =
-    g_param_spec_boolean ("allow-long-swipes",
-                          "Allow long swipes",
-                          "Whether to allow swiping for more than one page at a time",
+    g_param_spec_boolean ("allow-long-swipes", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwCarousel:reveal-duration:
    *
    * Page reveal duration, in milliseconds.
    *
+   * Reveal duration is used when animating adding or removing pages.
+   *
    * Since: 1.0
    */
   props[PROP_REVEAL_DURATION] =
-    g_param_spec_uint ("reveal-duration",
-                       "Reveal duration",
-                       "Page reveal duration",
+    g_param_spec_uint ("reveal-duration", NULL, NULL,
                        0,
                        G_MAXUINT,
                        0,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_override_property (object_class,
                                     PROP_ORIENTATION,
@@ -1492,9 +1479,9 @@ adw_carousel_get_n_pages (AdwCarousel *self)
  * adw_carousel_get_position: (attributes org.gtk.Method.get_property=position)
  * @self: a carousel
  *
- * Gets current scroll position in @self.
+ * Gets current scroll position in @self, unitless.
  *
- * It's unitless, 1 matches 1 page.
+ * 1 matches 1 page. Use [method@Carousel.scroll_to] for changing it.
  *
  * Returns: the scroll position
  *
@@ -1533,6 +1520,9 @@ adw_carousel_get_interactive (AdwCarousel *self)
  *
  * Sets whether @self can be navigated.
  *
+ * This can be used to temporarily disable the carousel to only allow navigating
+ * it in a certain state.
+ *
  * Since: 1.0
  */
 void
@@ -1618,6 +1608,12 @@ adw_carousel_get_scroll_params (AdwCarousel *self)
  *
  * Sets the scroll animation spring parameters for @self.
  *
+ * The default value is equivalent to:
+ *
+ * ```c
+ * adw_spring_params_new (1, 0.5, 500)
+ * ```
+ *
  * Since: 1.0
  */
 void
@@ -1660,6 +1656,8 @@ adw_carousel_get_allow_mouse_drag (AdwCarousel *self)
  *
  * Sets whether @self can be dragged with mouse pointer.
  *
+ * If @allow_mouse_drag is `FALSE`, dragging is only available on touch.
+ *
  * Since: 1.0
  */
 void
@@ -1703,6 +1701,8 @@ adw_carousel_get_allow_scroll_wheel (AdwCarousel *self)
  *
  * Sets whether @self will respond to scroll wheel events.
  *
+ * If @allow_scroll_wheel is `FALSE`, wheel events will be ignored.
+ *
  * Since: 1.0
  */
 void
@@ -1746,6 +1746,9 @@ adw_carousel_get_allow_long_swipes (AdwCarousel *self)
  *
  * Sets whether to allow swiping for more than one page at a time.
  *
+ * If @allow_long_swipes is `FALSE`, each swipe can only move to the adjacent
+ * pages.
+ *
  * Since: 1.0
  */
 void
@@ -1768,7 +1771,7 @@ adw_carousel_set_allow_long_swipes (AdwCarousel *self,
  * adw_carousel_get_reveal_duration: (attributes org.gtk.Method.get_property=reveal-duration)
  * @self: a carousel
  *
- * Gets duration of the animation used when adding or removing pages.
+ * Gets the page reveal duration, in milliseconds.
  *
  * Returns: the duration
  *
@@ -1787,7 +1790,9 @@ adw_carousel_get_reveal_duration (AdwCarousel *self)
  * @self: a carousel
  * @reveal_duration: the new reveal duration value
  *
- * Sets duration of the animation used when adding or removing pages.
+ * Sets the page reveal duration, in milliseconds.
+ *
+ * Reveal duration is used when animating adding or removing pages.
  *
  * Since: 1.0
  */
