@@ -353,16 +353,14 @@ adw_clamp_layout_class_init (AdwClampLayoutClass *klass)
    * Since: 1.0
    */
   props[PROP_MAXIMUM_SIZE] =
-      g_param_spec_int ("maximum-size",
-                        "Maximum size",
-                        "The maximum size allocated to the child",
-                        0, G_MAXINT, 600,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_int ("maximum-size", NULL, NULL,
+                      0, G_MAXINT, 600,
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwClampLayout:tightening-threshold: (attributes org.gtk.Property.get=adw_clamp_layout_get_tightening_threshold org.gtk.Property.set=adw_clamp_layout_set_tightening_threshold)
    *
-   * The size above which the child is clamped.
+   * The size above which the children are clamped.
    *
    * Starting from this size, the layout will tighten its grip on the children,
    * slowly allocating less and less of the available size up to the maximum
@@ -380,11 +378,9 @@ adw_clamp_layout_class_init (AdwClampLayoutClass *klass)
    * Since: 1.0
    */
   props[PROP_TIGHTENING_THRESHOLD] =
-      g_param_spec_int ("tightening-threshold",
-                        "Tightening threshold",
-                        "The size above which the children are clamped",
-                        0, G_MAXINT, 400,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_int ("tightening-threshold", NULL, NULL,
+                      0, G_MAXINT, 400,
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 }
@@ -436,6 +432,8 @@ adw_clamp_layout_get_maximum_size (AdwClampLayout *self)
  *
  * Sets the maximum size allocated to the children.
  *
+ * It is the width if the layout is horizontal, or the height if it is vertical.
+ *
  * Since: 1.0
  */
 void
@@ -479,6 +477,19 @@ adw_clamp_layout_get_tightening_threshold (AdwClampLayout *self)
  *
  * Sets the size above which the children are clamped.
  *
+ * Starting from this size, the layout will tighten its grip on the children,
+ * slowly allocating less and less of the available size up to the maximum
+ * allocated size. Below that threshold and below the maximum size, the children
+ * will be allocated all the available size.
+ *
+ * If the threshold is greater than the maximum size to allocate to the
+ * children, they will be allocated the whole size up to the maximum. If the
+ * threshold is lower than the minimum size to allocate to the children, that
+ * size will be used as the tightening threshold.
+ *
+ * Effectively, tightening the grip on a child before it reaches its maximum
+ * size makes transitions to and from the maximum size smoother when resizing.
+ *
  * Since: 1.0
  */
 void
