@@ -177,11 +177,9 @@ adw_clamp_class_init (AdwClampClass *klass)
    * Since: 1.0
    */
   props[PROP_CHILD] =
-      g_param_spec_object ("child",
-                           "Child",
-                           "The child widget",
-                           GTK_TYPE_WIDGET,
-                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_object ("child", NULL, NULL,
+                         GTK_TYPE_WIDGET,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwClamp:maximum-size: (attributes org.gtk.Property.get=adw_clamp_get_maximum_size org.gtk.Property.set=adw_clamp_set_maximum_size)
@@ -193,11 +191,9 @@ adw_clamp_class_init (AdwClampClass *klass)
    * Since: 1.0
    */
   props[PROP_MAXIMUM_SIZE] =
-      g_param_spec_int ("maximum-size",
-                        "Maximum size",
-                        "The maximum size allocated to the child",
-                        0, G_MAXINT, 600,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_int ("maximum-size", NULL, NULL,
+                      0, G_MAXINT, 600,
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwClamp:tightening-threshold: (attributes org.gtk.Property.get=adw_clamp_get_tightening_threshold org.gtk.Property.set=adw_clamp_set_tightening_threshold)
@@ -220,11 +216,9 @@ adw_clamp_class_init (AdwClampClass *klass)
    * Since: 1.0
    */
   props[PROP_TIGHTENING_THRESHOLD] =
-      g_param_spec_int ("tightening-threshold",
-                        "Tightening threshold",
-                        "The size above which the child is clamped",
-                        0, G_MAXINT, 400,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_int ("tightening-threshold", NULL, NULL,
+                      0, G_MAXINT, 400,
+                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -349,6 +343,8 @@ adw_clamp_get_maximum_size (AdwClamp *self)
  *
  * Sets the maximum size allocated to the child.
  *
+ * It is the width if the clamp is horizontal, or the height if it is vertical.
+ *
  * Since: 1.0
  */
 void
@@ -398,6 +394,19 @@ adw_clamp_get_tightening_threshold (AdwClamp *self)
  *
  * Sets the size above which the child is clamped.
  *
+ * Starting from this size, the clamp will tighten its grip on the child, slowly
+ * allocating less and less of the available size up to the maximum allocated
+ * size. Below that threshold and below the maximum size, the child will be
+ * allocated all the available size.
+ *
+ * If the threshold is greater than the maximum size to allocate to the child,
+ * the child will be allocated all the size up to the maximum. If the threshold
+ * is lower than the minimum size to allocate to the child, that size will be
+ * used as the tightening threshold.
+ *
+ * Effectively, tightening the grip on the child before it reaches its maximum
+ * size makes transitions to and from the maximum size smoother when resizing.
+ *
  * Since: 1.0
  */
 void
