@@ -27,6 +27,26 @@
  * choices. The row displays the selected choice. When activated, the row
  * displays a popover which allows the user to make a new choice.
  *
+ * Example of an `AdwComboRow` UI definition:
+ * ```xml
+ * <object class="AdwComboRow">
+ *   <property name="title" translatable="yes">Combo Row</property>
+ *   <property name="model">
+ *     <object class="GtkStringList">
+ *       <items>
+ *         <item translatable="yes">Foo</item>
+ *         <item translatable="yes">Bar</item>
+ *         <item translatable="yes">Baz</item>
+ *       </items>
+ *     </object>
+ *   </property>
+ * </object>
+ * ```
+ * 
+ * The [property@ComboRow:selected] and [property@ComboRow:selected-item]
+ * properties can be used to keep track of the selected item and react to their
+ * changes.
+ *
  * `AdwComboRow` mirrors [class@Gtk.DropDown], see that widget for details.
  *
  * `AdwComboRow` is [property@Gtk.ListBoxRow:activatable] if a model is set.
@@ -73,9 +93,9 @@ G_DEFINE_TYPE_WITH_PRIVATE (AdwComboRow, adw_combo_row, ADW_TYPE_ACTION_ROW)
 
 enum {
   PROP_0,
-  PROP_MODEL,
   PROP_SELECTED,
   PROP_SELECTED_ITEM,
+  PROP_MODEL,
   PROP_FACTORY,
   PROP_LIST_FACTORY,
   PROP_EXPRESSION,
@@ -288,15 +308,15 @@ adw_combo_row_get_property (GObject    *object,
   AdwComboRow *self = ADW_COMBO_ROW (object);
 
   switch (prop_id) {
-  case PROP_MODEL:
-    g_value_set_object (value, adw_combo_row_get_model (self));
-    break;
   case PROP_SELECTED:
     g_value_set_uint (value, adw_combo_row_get_selected (self));
     break;
   case PROP_SELECTED_ITEM:
     g_value_set_object (value, adw_combo_row_get_selected_item (self));
     break;
+  case PROP_MODEL:
+    g_value_set_object (value, adw_combo_row_get_model (self));
+    break;
   case PROP_FACTORY:
     g_value_set_object (value, adw_combo_row_get_factory (self));
     break;
@@ -323,12 +343,12 @@ adw_combo_row_set_property (GObject      *object,
   AdwComboRow *self = ADW_COMBO_ROW (object);
 
   switch (prop_id) {
-  case PROP_MODEL:
-    adw_combo_row_set_model (self, g_value_get_object (value));
-    break;
   case PROP_SELECTED:
     adw_combo_row_set_selected (self, g_value_get_uint (value));
     break;
+  case PROP_MODEL:
+    adw_combo_row_set_model (self, g_value_get_object (value));
+    break;
   case PROP_FACTORY:
     adw_combo_row_set_factory (self, g_value_get_object (value));
     break;
@@ -415,20 +435,6 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
 
   row_class->activate = adw_combo_row_activate;
 
-  /**
-   * AdwComboRow:model: (attributes org.gtk.Property.get=adw_combo_row_get_model org.gtk.Property.set=adw_combo_row_set_model)
-   *
-   * Model for the displayed items.
-   *
-   * Since: 1.0
-   */
-  props[PROP_MODEL] =
-    g_param_spec_object ("model",
-                         "Model",
-                         "Model for the displayed items",
-                         G_TYPE_LIST_MODEL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
   /**
    * AdwComboRow:selected: (attributes org.gtk.Property.get=adw_combo_row_get_selected org.gtk.Property.set=adw_combo_row_set_selected)
    *
@@ -440,11 +446,9 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
    * Since: 1.0
    */
   props[PROP_SELECTED] =
-    g_param_spec_uint ("selected",
-                       "Selected",
-                       "Position of the selected item",
+    g_param_spec_uint ("selected", NULL, NULL,
                        0, G_MAXUINT, GTK_INVALID_LIST_POSITION,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwComboRow:selected-item: (attributes org.gtk.Property.get=adw_combo_row_get_selected_item)
@@ -454,11 +458,21 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
    * Since: 1.0
    */
   props[PROP_SELECTED_ITEM] =
-    g_param_spec_object ("selected-item",
-                         "Selected Item",
-                         "The selected item",
+    g_param_spec_object ("selected-item", NULL, NULL,
                          G_TYPE_OBJECT,
-                         G_PARAM_READABLE);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * AdwComboRow:model: (attributes org.gtk.Property.get=adw_combo_row_get_model org.gtk.Property.set=adw_combo_row_set_model)
+   *
+   * The model that provides the displayed items.
+   *
+   * Since: 1.0
+   */
+  props[PROP_MODEL] =
+    g_param_spec_object ("model", NULL, NULL,
+                         G_TYPE_LIST_MODEL,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwComboRow:factory: (attributes org.gtk.Property.get=adw_combo_row_get_factory org.gtk.Property.set=adw_combo_row_set_factory)
@@ -471,11 +485,9 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
    * Since: 1.0
    */
   props[PROP_FACTORY] =
-    g_param_spec_object ("factory",
-                         "Factory",
-                         "Factory for populating list items",
+    g_param_spec_object ("factory", NULL, NULL,
                          GTK_TYPE_LIST_ITEM_FACTORY,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwComboRow:list-factory: (attributes org.gtk.Property.get=adw_combo_row_get_list_factory org.gtk.Property.set=adw_combo_row_set_list_factory)
@@ -487,21 +499,20 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
    * Since: 1.0
    */
   props[PROP_LIST_FACTORY] =
-    g_param_spec_object ("list-factory",
-                         "List Factory",
-                         "Factory for populating list items",
+    g_param_spec_object ("list-factory", NULL, NULL,
                          GTK_TYPE_LIST_ITEM_FACTORY,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwComboRow:expression: (type GtkExpression) (attributes org.gtk.Property.get=adw_combo_row_get_expression org.gtk.Property.set=adw_combo_row_set_expression)
    *
    * An expression used to obtain strings from items.
    *
-   * It's used to bind strings to labels produced by the default factory.
+   * The expression must have a value type of `G_TYPE_STRING`.
    *
-   * If [property@ComboRow:factory] is not set, the expression is also used to
-   * bind strings to labels produced by a default factory.
+   * It's used to bind strings to labels produced by the default factory if
+   * [property@ComboRow:factory] is not set, or when
+   * [property@ComboRow:use-subtitle] is set to `TRUE`.
    *
    * Since: 1.0
    */
@@ -509,7 +520,7 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
     gtk_param_spec_expression ("expression",
                                "Expression",
                                "Expression to determine strings to search for",
-                               G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwComboRow:use-subtitle: (attributes org.gtk.Property.get=adw_combo_row_get_use_subtitle org.gtk.Property.set=adw_combo_row_set_use_subtitle)
@@ -519,16 +530,17 @@ adw_combo_row_class_init (AdwComboRowClass *klass)
    * If you use a custom list item factory, you will need to give the row a
    * name conversion expression with [property@ComboRow:expression].
    *
-   * If `TRUE`, you should not access [property@ActionRow:subtitle].
+   * If set to `TRUE`, you should not access [property@ActionRow:subtitle].
+   *
+   * The subtitle is interpreted as Pango markup if
+   * [property@PreferencesRow:use-markup] is set to `TRUE`.
    *
    * Since: 1.0
    */
   props[PROP_USE_SUBTITLE] =
-    g_param_spec_boolean ("use-subtitle",
-                          "Use subtitle",
-                          "Whether to use the current value as the subtitle",
+    g_param_spec_boolean ("use-subtitle", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -549,6 +561,7 @@ adw_combo_row_init (AdwComboRow *self)
 {
   gtk_widget_init_template (GTK_WIDGET (self));
 
+  adw_preferences_row_set_use_markup (ADW_PREFERENCES_ROW (self), FALSE);
   set_default_factory (self);
   model_changed (self);
 }
@@ -675,7 +688,7 @@ adw_combo_row_get_model (AdwComboRow *self)
  * @self: a combo row
  * @model: (nullable) (transfer none): the model to use
  *
- * Sets the [iface@Gio.ListModel] to use.
+ * Sets the model that provides the displayed items.
  *
  * Since: 1.0
  */
@@ -738,7 +751,7 @@ adw_combo_row_set_model (AdwComboRow *self,
  * adw_combo_row_get_factory: (attributes org.gtk.Method.get_property=factory)
  * @self: a combo row
  *
- * Gets the factory that's currently used to populate list items.
+ * Gets the factory for populating list items.
  *
  * Returns: (nullable) (transfer none): the factory in use
  *
@@ -761,7 +774,10 @@ adw_combo_row_get_factory (AdwComboRow *self)
  * @self: a combo row
  * @factory: (nullable) (transfer none): the factory to use
  *
- * Sets the `GtkListItemFactory` to use for populating list items.
+ * Sets the factory for populating list items.
+ *
+ * This factory is always used for the item in the row. It is also used for
+ * items in the popup unless [property@ComboRow:list-factory] is set.
  *
  * Since: 1.0
  */
@@ -791,7 +807,7 @@ adw_combo_row_set_factory (AdwComboRow        *self,
  * adw_combo_row_get_list_factory: (attributes org.gtk.Method.get_property=list-factory)
  * @self: a combo row
  *
- * Gets the factory that's currently used to populate list items in the popup.
+ * Gets the factory for populating list items in the popup.
  *
  * Returns: (nullable) (transfer none): the factory in use
  *
@@ -814,7 +830,9 @@ adw_combo_row_get_list_factory (AdwComboRow *self)
  * @self: a combo row
  * @factory: (nullable) (transfer none): the factory to use
  *
- * Sets the `GtkListItemFactory` to use for populating list items in the popup.
+ * Sets the factory for populating list items in the popup.
+ *
+ * If this is not set, [property@ComboRow:factory] is used.
  *
  * Since: 1.0
  */
@@ -871,6 +889,10 @@ adw_combo_row_get_expression (AdwComboRow *self)
  *
  * The expression must have a value type of `G_TYPE_STRING`.
  *
+ * It's used to bind strings to labels produced by the default factory if
+ * [property@ComboRow:factory] is not set, or when
+ * [property@ComboRow:use-subtitle] is set to `TRUE`.
+ *
  * Since: 1.0
  */
 void
@@ -928,6 +950,14 @@ adw_combo_row_get_use_subtitle (AdwComboRow *self)
  *
  * Sets whether to use the current value as the subtitle.
  *
+ * If you use a custom list item factory, you will need to give the row a
+ * name conversion expression with [property@ComboRow:expression].
+ *
+ * If set to `TRUE`, you should not access [property@ActionRow:subtitle].
+ *
+ * The subtitle is interpreted as Pango markup if
+ * [property@PreferencesRow:use-markup] is set to `TRUE`.
+ *
  * Since: 1.0
  */
 void
