@@ -110,11 +110,9 @@ adw_enum_list_item_class_init (AdwEnumListItemClass *klass)
    * Since: 1.0
    */
   value_props[VALUE_PROP_VALUE] =
-    g_param_spec_int ("value",
-                      "Value",
-                      "The enum value",
+    g_param_spec_int ("value", NULL, NULL,
                       G_MININT, G_MAXINT, 0,
-                      G_PARAM_READABLE);
+                      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwEnumListItem:name: (attributes org.gtk.Property.get=adw_enum_list_item_get_name)
@@ -124,11 +122,9 @@ adw_enum_list_item_class_init (AdwEnumListItemClass *klass)
    * Since: 1.0
    */
   value_props[VALUE_PROP_NAME] =
-    g_param_spec_string ("name",
-                         "Name",
-                         "The enum value name",
+    g_param_spec_string ("name", NULL, NULL,
                          NULL,
-                         G_PARAM_READABLE);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwEnumListItem:nick: (attributes org.gtk.Property.get=adw_enum_list_item_get_nick)
@@ -138,11 +134,9 @@ adw_enum_list_item_class_init (AdwEnumListItemClass *klass)
    * Since: 1.0
    */
   value_props[VALUE_PROP_NICK] =
-    g_param_spec_string ("nick",
-                         "Nick",
-                         "The enum value nick",
+    g_param_spec_string ("nick", NULL, NULL,
                          NULL,
-                         G_PARAM_READABLE);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_VALUE_PROP, value_props);
 }
@@ -233,13 +227,8 @@ static void
 adw_enum_list_model_finalize (GObject *object)
 {
   AdwEnumListModel *self = ADW_ENUM_LIST_MODEL (object);
-  guint i;
-
-  for (i = 0; i < self->enum_class->n_values; i++)
-    g_object_unref (self->objects[i]);
 
   g_clear_pointer (&self->enum_class, g_type_class_unref);
-
   g_clear_pointer (&self->objects, g_free);
 
   G_OBJECT_CLASS (adw_enum_list_model_parent_class)->finalize (object);
@@ -297,11 +286,9 @@ adw_enum_list_model_class_init (AdwEnumListModelClass *klass)
    * Since: 1.0
    */
   props[PROP_ENUM_TYPE] =
-    g_param_spec_gtype ("enum-type",
-                        "Enum type",
-                        "The type of the enum represented by the model",
+    g_param_spec_gtype ("enum-type", NULL, NULL,
                         G_TYPE_ENUM,
-                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 }
