@@ -73,7 +73,7 @@
  *
  * The `AdwFlap` implementation of the [iface@Gtk.Buildable] interface supports
  * setting the flap child by specifying “flap” as the “type” attribute of a
- * <child> element, and separator by specifying “separator”. Specifying
+ * `<child>` element, and separator by specifying “separator”. Specifying
  * “content” child type or omitting it results in setting the content child.
  *
  * ## CSS nodes
@@ -988,7 +988,7 @@ adw_flap_measure (GtkWidget      *widget,
     }
 
     min = MAX (content_min + (int) round ((flap_min + separator_min) * min_progress), flap_min);
-    nat = MAX (content_nat + (int) round ((flap_nat + separator_nat) * nat_progress), flap_nat);
+    nat = MAX (content_nat + (int) round ((flap_nat + separator_min) * nat_progress), flap_nat);
   } else {
     min = MAX (MAX (content_min, flap_min), separator_min);
     nat = MAX (MAX (content_nat, flap_nat), separator_nat);
@@ -1230,9 +1230,10 @@ adw_flap_dispose (GObject *object)
 {
   AdwFlap *self = ADW_FLAP (object);
 
-  g_clear_pointer (&self->flap.widget, gtk_widget_unparent);
-  g_clear_pointer (&self->separator.widget, gtk_widget_unparent);
-  g_clear_pointer (&self->content.widget, gtk_widget_unparent);
+  adw_flap_set_flap (self, NULL);
+  adw_flap_set_separator (self, NULL);
+  adw_flap_set_content (self, NULL);
+
   g_clear_pointer (&self->shield, gtk_widget_unparent);
 
   g_clear_object (&self->shadow_helper);
@@ -1267,17 +1268,14 @@ adw_flap_class_init (AdwFlapClass *klass)
    *
    * The content widget.
    *
-   * It's always displayed when unfolded, and partially visible
-   * when folded.
+   * It's always displayed when unfolded, and partially visible when folded.
    *
    * Since: 1.0
    */
   props[PROP_CONTENT] =
-    g_param_spec_object ("content",
-                         "Content",
-                         "The content widget",
+    g_param_spec_object ("content", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:flap: (attributes org.gtk.Property.get=adw_flap_get_flap org.gtk.Property.set=adw_flap_set_flap)
@@ -1289,11 +1287,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_FLAP] =
-    g_param_spec_object ("flap",
-                         "Flap",
-                         "The flap widget",
+    g_param_spec_object ("flap", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:separator: (attributes org.gtk.Property.get=adw_flap_get_separator org.gtk.Property.set=adw_flap_set_separator)
@@ -1307,11 +1303,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_SEPARATOR] =
-    g_param_spec_object ("separator",
-                         "Separator",
-                         "The separator widget",
+    g_param_spec_object ("separator", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:flap-position: (attributes org.gtk.Property.get=adw_flap_get_flap_position org.gtk.Property.set=adw_flap_set_flap_position)
@@ -1324,12 +1318,10 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_FLAP_POSITION] =
-    g_param_spec_enum ("flap-position",
-                       "Flap Position",
-                       "The flap position",
+    g_param_spec_enum ("flap-position", NULL, NULL,
                        GTK_TYPE_PACK_TYPE,
                        GTK_PACK_START,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:reveal-flap: (attributes org.gtk.Property.get=adw_flap_get_reveal_flap org.gtk.Property.set=adw_flap_set_reveal_flap)
@@ -1339,11 +1331,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_REVEAL_FLAP] =
-    g_param_spec_boolean ("reveal-flap",
-                          "Reveal Flap",
-                          "Whether the flap is revealed",
+    g_param_spec_boolean ("reveal-flap", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:reveal-params: (attributes org.gtk.Property.get=adw_flap_get_reveal_params org.gtk.Property.set=adw_flap_set_reveal_params)
@@ -1359,11 +1349,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_REVEAL_PARAMS] =
-    g_param_spec_boxed ("reveal-params",
-                        "Reveal Parameters",
-                        "The reveal animation spring parameters",
+    g_param_spec_boxed ("reveal-params", NULL, NULL,
                         ADW_TYPE_SPRING_PARAMS,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:reveal-progress: (attributes org.gtk.Property.get=adw_flap_get_reveal_progress)
@@ -1377,26 +1365,22 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_REVEAL_PROGRESS] =
-    g_param_spec_double ("reveal-progress",
-                          "Reveal Progress",
-                          "The current reveal transition progress",
+    g_param_spec_double ("reveal-progress", NULL, NULL,
                           0.0, 1.0, 1.0,
-                          G_PARAM_READABLE);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy org.gtk.Property.set=adw_flap_set_fold_policy)
+   * AdwFlap:fold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_policy)
    *
    * The fold policy for the flap.
    *
    * Since: 1.0
    */
   props[PROP_FOLD_POLICY] =
-    g_param_spec_enum ("fold-policy",
-                       "Fold Policy",
-                       "The fold policy for the flap",
+    g_param_spec_enum ("fold-policy", NULL, NULL,
                        ADW_TYPE_FLAP_FOLD_POLICY,
                        ADW_FLAP_FOLD_POLICY_AUTO,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:fold-threshold-policy: (attributes org.gtk.Property.get=adw_flap_get_fold_threshold_policy org.gtk.Property.set=adw_flap_set_fold_threshold_policy)
@@ -1413,12 +1397,10 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_FOLD_THRESHOLD_POLICY] =
-    g_param_spec_enum ("fold-threshold-policy",
-                       "Fold Threshold Policy",
-                       "Determines when the flap will fold",
+    g_param_spec_enum ("fold-threshold-policy", NULL, NULL,
                        ADW_TYPE_FOLD_THRESHOLD_POLICY,
                        ADW_FOLD_THRESHOLD_POLICY_MINIMUM,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:fold-duration: (attributes org.gtk.Property.get=adw_flap_get_fold_duration org.gtk.Property.set=adw_flap_set_fold_duration)
@@ -1428,12 +1410,10 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_FOLD_DURATION] =
-    g_param_spec_uint ("fold-duration",
-                       "Fold Duration",
-                       "The fold transition animation duration, in milliseconds",
+    g_param_spec_uint ("fold-duration", NULL, NULL,
                        0, G_MAXINT,
                        250,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:folded: (attributes org.gtk.Property.get=adw_flap_get_folded)
@@ -1445,11 +1425,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_FOLDED] =
-    g_param_spec_boolean ("folded",
-                          "Folded",
-                          "Whether the flap is currently folded",
+    g_param_spec_boolean ("folded", NULL, NULL,
                           FALSE,
-                          G_PARAM_READABLE);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwFlap:locked: (attributes org.gtk.Property.get=adw_flap_get_locked org.gtk.Property.set=adw_flap_set_locked)
@@ -1463,11 +1441,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_LOCKED] =
-    g_param_spec_boolean ("locked",
-                          "Locked",
-                          "Whether the flap is locked",
+    g_param_spec_boolean ("locked", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:transition-type: (attributes org.gtk.Property.get=adw_flap_get_transition_type org.gtk.Property.set=adw_flap_set_transition_type)
@@ -1482,12 +1458,10 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_TRANSITION_TYPE] =
-    g_param_spec_enum ("transition-type",
-                       "Transition Type",
-                       "The type of animation used for reveal and fold transitions",
+    g_param_spec_enum ("transition-type", NULL, NULL,
                        ADW_TYPE_FLAP_TRANSITION_TYPE,
                        ADW_FLAP_TRANSITION_TYPE_OVER,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:modal: (attributes org.gtk.Property.get=adw_flap_get_modal org.gtk.Property.set=adw_flap_set_modal)
@@ -1501,11 +1475,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_MODAL] =
-    g_param_spec_boolean ("modal",
-                          "Modal",
-                          "Whether the flap is modal",
+    g_param_spec_boolean ("modal", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:swipe-to-open: (attributes org.gtk.Property.get=adw_flap_get_swipe_to_open org.gtk.Property.set=adw_flap_set_swipe_to_open)
@@ -1518,11 +1490,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_SWIPE_TO_OPEN] =
-    g_param_spec_boolean ("swipe-to-open",
-                          "Swipe to Open",
-                          "Whether the flap can be opened with a swipe gesture",
+    g_param_spec_boolean ("swipe-to-open", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwFlap:swipe-to-close: (attributes org.gtk.Property.get=adw_flap_get_swipe_to_close org.gtk.Property.set=adw_flap_set_swipe_to_close)
@@ -1535,11 +1505,9 @@ adw_flap_class_init (AdwFlapClass *klass)
    * Since: 1.0
    */
   props[PROP_SWIPE_TO_CLOSE] =
-    g_param_spec_boolean ("swipe-to-close",
-                          "Swipe to Close",
-                          "Whether the flap can be closed with a swipe gesture",
+    g_param_spec_boolean ("swipe-to-close", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -1859,6 +1827,8 @@ adw_flap_get_content (AdwFlap *self)
  *
  * Sets the content widget for @self.
  *
+ * It's always displayed when unfolded, and partially visible when folded.
+ *
  * Since: 1.0
  */
 void
@@ -1909,6 +1879,8 @@ adw_flap_get_flap (AdwFlap *self)
  *
  * Sets the flap widget for @self.
  *
+ * It's only visible when [property@Flap:reveal-progress] is greater than 0.
+ *
  * Since: 1.0
  */
 void
@@ -1960,6 +1932,10 @@ adw_flap_get_separator (AdwFlap *self)
  *
  * Sets the separator widget for @self.
  *
+ * It's displayed between content and flap when there's no shadow to display.
+ * When exactly it's visible depends on the [property@Flap:transition-type]
+ * value.
+ *
  * Since: 1.0
  */
 void
@@ -2010,6 +1986,9 @@ adw_flap_get_flap_position (AdwFlap *self)
  *
  * Sets the flap position for @self.
  *
+ * If it's set to `GTK_PACK_START`, the flap is displayed before the content,
+ * if `GTK_PACK_END`, it's displayed after the content.
+ *
  * Since: 1.0
  */
 void
@@ -2091,6 +2070,12 @@ adw_flap_get_reveal_params (AdwFlap *self)
  *
  * Sets the reveal animation spring parameters for @self.
  *
+ * The default value is equivalent to:
+ *
+ * ```c
+ * adw_spring_params_new (1, 0.5, 500)
+ * ```
+ *
  * Since: 1.0
  */
 void
@@ -2115,6 +2100,10 @@ adw_flap_set_reveal_params (AdwFlap         *self,
  *
  * Gets the current reveal progress for @self.
  *
+ * 0 means fully hidden, 1 means fully revealed.
+ *
+ * See [property@Flap:reveal-flap].
+ *
  * Returns: the current reveal progress for @self
  *
  * Since: 1.0
@@ -2186,11 +2175,60 @@ adw_flap_set_fold_policy (AdwFlap           *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLD_POLICY]);
 }
 
+/**
+ * adw_flap_get_fold_threshold_policy: (attributes org.gtk.Method.get_property=fold-threshold-policy)
+ * @self: a flap
+ *
+ * Gets the fold threshold policy for @self.
+ *
+ * Since: 1.0
+ */
+AdwFoldThresholdPolicy
+adw_flap_get_fold_threshold_policy (AdwFlap *self)
+{
+  g_return_val_if_fail (ADW_IS_FLAP (self), ADW_FOLD_THRESHOLD_POLICY_MINIMUM);
+
+  return self->fold_threshold_policy;
+}
+
+/**
+ * adw_flap_set_fold_threshold_policy: (attributes org.gtk.Method.set_property=fold-threshold-policy)
+ * @self: a flap
+ * @policy: the policy to use
+ *
+ * Sets the fold threshold policy for @self.
+ *
+ * If set to `ADW_FOLD_THRESHOLD_POLICY_MINIMUM`, flap will only fold when the
+ * children cannot fit anymore. With `ADW_FOLD_THRESHOLD_POLICY_NATURAL`, it
+ * will fold as soon as children don't get their natural size.
+ *
+ * This can be useful if you have a long ellipsizing label and want to let it
+ * ellipsize instead of immediately folding.
+ *
+ * Since: 1.0
+ */
+void
+adw_flap_set_fold_threshold_policy (AdwFlap                *self,
+                                    AdwFoldThresholdPolicy  policy)
+{
+  g_return_if_fail (ADW_IS_FLAP (self));
+  g_return_if_fail (policy <= ADW_FOLD_THRESHOLD_POLICY_NATURAL);
+
+  if (self->fold_threshold_policy == policy)
+    return;
+
+  self->fold_threshold_policy = policy;
+
+  gtk_widget_queue_allocate (GTK_WIDGET (self));
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLD_THRESHOLD_POLICY]);
+}
+
 /**
  * adw_flap_get_fold_duration: (attributes org.gtk.Method.get_property=fold-duration)
  * @self: a flap
  *
- * Gets the duration that fold transitions in @self will take.
+ * Gets the fold transition animation duration for @self, in milliseconds.
  *
  * Returns: the fold transition duration
  *
@@ -2209,7 +2247,7 @@ adw_flap_get_fold_duration (AdwFlap *self)
  * @self: a flap
  * @duration: the new duration, in milliseconds
  *
- * Sets the duration that fold transitions in @self will take.
+ * Sets the fold transition animation duration for @self, in milliseconds.
  *
  * Since: 1.0
  */
@@ -2233,6 +2271,8 @@ adw_flap_set_fold_duration (AdwFlap *self,
  *
  * Gets whether @self is currently folded.
  *
+ * See [property@Flap:fold-policy].
+ *
  * Returns: `TRUE` if @self is currently folded
  *
  * Since: 1.0
@@ -2270,6 +2310,10 @@ adw_flap_get_locked (AdwFlap *self)
  *
  * Sets whether @self is locked.
  *
+ * If `FALSE`, folding when the flap is revealed automatically closes it, and
+ * unfolding it when the flap is not revealed opens it. If `TRUE`,
+ * [property@Flap:reveal-flap] value never changes on its own.
+ *
  * Since: 1.0
  */
 void
@@ -2313,6 +2357,11 @@ adw_flap_get_transition_type (AdwFlap *self)
  *
  * Sets the type of animation used for reveal and fold transitions in @self.
  *
+ * [property@Flap:flap] is transparent by default, which means the content will
+ * be seen through it with `ADW_FLAP_TRANSITION_TYPE_OVER` transitions; add the
+ * [`.background`](style-classes.html#background) style class to it if this is
+ * unwanted.
+ *
  * Since: 1.0
  */
 void
@@ -2360,6 +2409,10 @@ adw_flap_get_modal (AdwFlap *self)
  *
  * Sets whether @self is modal.
  *
+ * If `TRUE`, clicking the content widget while flap is revealed, as well as
+ * pressing the <kbd>Esc</kbd> key, will close the flap. If `FALSE`, clicks are
+ * passed through to the content widget.
+ *
  * Since: 1.0
  */
 void
@@ -2408,6 +2461,9 @@ adw_flap_get_swipe_to_open (AdwFlap *self)
  *
  * Sets whether @self can be opened with a swipe gesture.
  *
+ * The area that can be swiped depends on the [property@Flap:transition-type]
+ * value.
+ *
  * Since: 1.0
  */
 void
@@ -2453,6 +2509,9 @@ adw_flap_get_swipe_to_close (AdwFlap *self)
  *
  * Sets whether @self can be closed with a swipe gesture.
  *
+ * The area that can be swiped depends on the [property@Flap:transition-type]
+ * value.
+ *
  * Since: 1.0
  */
 void
@@ -2472,45 +2531,3 @@ adw_flap_set_swipe_to_close (AdwFlap  *self,
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SWIPE_TO_CLOSE]);
 }
-
-/**
- * adw_flap_get_fold_threshold_policy: (attributes org.gtk.Method.get_property=fold-threshold-policy)
- * @self: a flap
- *
- * Gets the fold threshold policy for @self.
- *
- * Since: 1.0
- */
-AdwFoldThresholdPolicy
-adw_flap_get_fold_threshold_policy (AdwFlap *self)
-{
-  g_return_val_if_fail (ADW_IS_FLAP (self), ADW_FOLD_THRESHOLD_POLICY_MINIMUM);
-
-  return self->fold_threshold_policy;
-}
-
-/**
- * adw_flap_set_fold_threshold_policy: (attributes org.gtk.Method.set_property=fold-threshold-policy)
- * @self: a flap
- * @policy: the policy to use
- *
- * Sets the fold threshold policy for @self.
- *
- * Since: 1.0
- */
-void
-adw_flap_set_fold_threshold_policy (AdwFlap                *self,
-                                    AdwFoldThresholdPolicy  policy)
-{
-  g_return_if_fail (ADW_IS_FLAP (self));
-  g_return_if_fail (policy <= ADW_FOLD_THRESHOLD_POLICY_NATURAL);
-
-  if (self->fold_threshold_policy == policy)
-    return;
-
-  self->fold_threshold_policy = policy;
-
-  gtk_widget_queue_allocate (GTK_WIDGET (self));
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_FOLD_THRESHOLD_POLICY]);
-}
