@@ -406,11 +406,9 @@ adw_header_bar_class_init (AdwHeaderBarClass *class)
    * Since: 1.0
    */
   props[PROP_TITLE_WIDGET] =
-    g_param_spec_object ("title-widget",
-                         "Title Widget",
-                         "The title widget to display",
+    g_param_spec_object ("title-widget", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwHeaderBar:show-start-title-buttons: (attributes org.gtk.Property.get=adw_header_bar_get_show_start_title_buttons org.gtk.Property.set=adw_header_bar_set_show_start_title_buttons)
@@ -427,11 +425,9 @@ adw_header_bar_class_init (AdwHeaderBarClass *class)
    * Since: 1.0
    */
   props[PROP_SHOW_START_TITLE_BUTTONS] =
-    g_param_spec_boolean ("show-start-title-buttons",
-                          "Show start title buttons",
-                          "Whether to show title buttons at the start of the header bar",
+    g_param_spec_boolean ("show-start-title-buttons", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwHeaderBar:show-end-title-buttons: (attributes org.gtk.Property.get=adw_header_bar_get_show_end_title_buttons org.gtk.Property.set=adw_header_bar_set_show_end_title_buttons)
@@ -448,11 +444,9 @@ adw_header_bar_class_init (AdwHeaderBarClass *class)
    * Since: 1.0
    */
   props[PROP_SHOW_END_TITLE_BUTTONS] =
-    g_param_spec_boolean ("show-end-title-buttons",
-                          "Show end title buttons",
-                          "Whether to show title buttons at the end of the header bar",
+    g_param_spec_boolean ("show-end-title-buttons", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwHeaderBar:decoration-layout: (attributes org.gtk.Property.get=adw_header_bar_get_decoration_layout org.gtk.Property.set=adw_header_bar_set_decoration_layout)
@@ -473,11 +467,9 @@ adw_header_bar_class_init (AdwHeaderBarClass *class)
    * Since: 1.0
    */
   props[PROP_DECORATION_LAYOUT] =
-    g_param_spec_string ("decoration-layout",
-                         "Decoration Layout",
-                         "The layout for window decorations",
+    g_param_spec_string ("decoration-layout", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwHeaderBar:centering-policy: (attributes org.gtk.Property.get=adw_header_bar_get_centering_policy org.gtk.Property.set=adw_header_bar_set_centering_policy)
@@ -487,12 +479,10 @@ adw_header_bar_class_init (AdwHeaderBarClass *class)
    * Since: 1.0
    */
   props[PROP_CENTERING_POLICY] =
-    g_param_spec_enum ("centering-policy",
-                       "Centering policy",
-                       "The policy for aligning the center widget",
+    g_param_spec_enum ("centering-policy", NULL, NULL,
                        ADW_TYPE_CENTERING_POLICY,
                        ADW_CENTERING_POLICY_LOOSE,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -617,61 +607,6 @@ adw_header_bar_pack_end (AdwHeaderBar *self,
   gtk_box_prepend (GTK_BOX (self->end_box), child);
 }
 
-/**
- * adw_header_bar_set_title_widget: (attributes org.gtk.Method.set_property=title-widget)
- * @self: a header bar
- * @title_widget: (nullable): a widget to use for a title
- *
- * Sets the title widget for @self.
- *
- * Since: 1.0
- */
-void
-adw_header_bar_set_title_widget (AdwHeaderBar *self,
-                                 GtkWidget    *title_widget)
-{
-  g_return_if_fail (ADW_IS_HEADER_BAR (self));
-
-  if (title_widget)
-    g_return_if_fail (GTK_IS_WIDGET (title_widget));
-
-  /* No need to do anything if the title widget stays the same */
-  if (self->title_widget == title_widget)
-    return;
-
-  gtk_center_box_set_center_widget (GTK_CENTER_BOX (self->center_box), NULL);
-  self->title_widget = NULL;
-
-  if (title_widget != NULL) {
-    self->title_widget = title_widget;
-
-    gtk_center_box_set_center_widget (GTK_CENTER_BOX (self->center_box), title_widget);
-
-    self->title_label = NULL;
-  } else if (self->title_label == NULL)
-    construct_title_label (self);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TITLE_WIDGET]);
-}
-
-/**
- * adw_header_bar_get_title_widget: (attributes org.gtk.Method.get_property=title-widget)
- * @self: a header bar
- *
- * Gets the title widget widget of @self.
- *
- * Returns: (nullable) (transfer none): the title widget
- *
- * Since: 1.0
- */
-GtkWidget *
-adw_header_bar_get_title_widget (AdwHeaderBar *self)
-{
-  g_return_val_if_fail (ADW_IS_HEADER_BAR (self), NULL);
-
-  return self->title_widget;
-}
-
 /**
  * adw_header_bar_remove:
  * @self: a header bar
@@ -705,6 +640,76 @@ adw_header_bar_remove (AdwHeaderBar *self,
     ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, child);
 }
 
+/**
+ * adw_header_bar_get_title_widget: (attributes org.gtk.Method.get_property=title-widget)
+ * @self: a header bar
+ *
+ * Gets the title widget widget of @self.
+ *
+ * Returns: (nullable) (transfer none): the title widget
+ *
+ * Since: 1.0
+ */
+GtkWidget *
+adw_header_bar_get_title_widget (AdwHeaderBar *self)
+{
+  g_return_val_if_fail (ADW_IS_HEADER_BAR (self), NULL);
+
+  return self->title_widget;
+}
+
+/**
+ * adw_header_bar_set_title_widget: (attributes org.gtk.Method.set_property=title-widget)
+ * @self: a header bar
+ * @title_widget: (nullable): a widget to use for a title
+ *
+ * Sets the title widget for @self.
+ *
+ * When set to `NULL`, the header bar will display the title of the window it
+ * is contained in.
+ *
+ * To use a different title, use [class@WindowTitle]:
+ *
+ * ```xml
+ * <object class="AdwHeaderBar">
+ *   <property name="title-widget">
+ *     <object class="AdwWindowTitle">
+ *       <property name="title" translatable="yes">Title</property>
+ *     </object>
+ *   </property>
+ * </object>
+ * ```
+ *
+ * Since: 1.0
+ */
+void
+adw_header_bar_set_title_widget (AdwHeaderBar *self,
+                                 GtkWidget    *title_widget)
+{
+  g_return_if_fail (ADW_IS_HEADER_BAR (self));
+
+  if (title_widget)
+    g_return_if_fail (GTK_IS_WIDGET (title_widget));
+
+  /* No need to do anything if the title widget stays the same */
+  if (self->title_widget == title_widget)
+    return;
+
+  gtk_center_box_set_center_widget (GTK_CENTER_BOX (self->center_box), NULL);
+  self->title_widget = NULL;
+
+  if (title_widget != NULL) {
+    self->title_widget = title_widget;
+
+    gtk_center_box_set_center_widget (GTK_CENTER_BOX (self->center_box), title_widget);
+
+    self->title_label = NULL;
+  } else if (self->title_label == NULL)
+    construct_title_label (self);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TITLE_WIDGET]);
+}
+
 /**
  * adw_header_bar_get_show_start_title_buttons: (attributes org.gtk.Method.get_property=show-start-title-buttons)
  * @self: a header bar
@@ -730,6 +735,12 @@ adw_header_bar_get_show_start_title_buttons (AdwHeaderBar *self)
  *
  * Sets whether to show title buttons at the start of @self.
  *
+ * See [property@HeaderBar:show-end-title-buttons] for the other side.
+ *
+ * Which buttons are actually shown and where is determined by the
+ * [property@HeaderBar:decoration-layout] property, and by the state of the
+ * window (e.g. a close button will not be shown if the window can't be closed).
+ *
  * Since: 1.0
  */
 void
@@ -782,6 +793,12 @@ adw_header_bar_get_show_end_title_buttons (AdwHeaderBar *self)
  *
  * Sets whether to show title buttons at the end of @self.
  *
+ * See [property@HeaderBar:show-start-title-buttons] for the other side.
+ *
+ * Which buttons are actually shown and where is determined by the
+ * [property@HeaderBar:decoration-layout] property, and by the state of the
+ * window (e.g. a close button will not be shown if the window can't be closed).
+ *
  * Since: 1.0
  */
 void
@@ -809,27 +826,6 @@ adw_header_bar_set_show_end_title_buttons (AdwHeaderBar *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SHOW_END_TITLE_BUTTONS]);
 }
 
-/**
- * adw_header_bar_set_decoration_layout: (attributes org.gtk.Method.set_property=decoration-layout)
- * @self: a header bar
- * @layout: (nullable): a decoration layout
- *
- * Sets the decoration layout for @self.
- *
- * Since: 1.0
- */
-void
-adw_header_bar_set_decoration_layout (AdwHeaderBar *self,
-                                      const char   *layout)
-{
-  g_return_if_fail (ADW_IS_HEADER_BAR (self));
-
-  g_clear_pointer (&self->decoration_layout, g_free);
-  self->decoration_layout = g_strdup (layout);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_DECORATION_LAYOUT]);
-}
-
 /**
  * adw_header_bar_get_decoration_layout: (attributes org.gtk.Method.get_property=decoration-layout)
  * @self: a header bar
@@ -848,6 +844,38 @@ adw_header_bar_get_decoration_layout (AdwHeaderBar *self)
   return self->decoration_layout;
 }
 
+/**
+ * adw_header_bar_set_decoration_layout: (attributes org.gtk.Method.set_property=decoration-layout)
+ * @self: a header bar
+ * @layout: (nullable): a decoration layout
+ *
+ * Sets the decoration layout for @self.
+ *
+ * If this property is not set, the
+ * [property@Gtk.Settings:gtk-decoration-layout] setting is used.
+ *
+ * The format of the string is button names, separated by commas. A colon
+ * separates the buttons that should appear at the start from those at the end.
+ * Recognized button names are minimize, maximize, close and icon (the window
+ * icon).
+ *
+ * For example, “icon:minimize,maximize,close” specifies an icon at the start,
+ * and minimize, maximize and close buttons at the end.
+ *
+ * Since: 1.0
+ */
+void
+adw_header_bar_set_decoration_layout (AdwHeaderBar *self,
+                                      const char   *layout)
+{
+  g_return_if_fail (ADW_IS_HEADER_BAR (self));
+
+  g_clear_pointer (&self->decoration_layout, g_free);
+  self->decoration_layout = g_strdup (layout);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_DECORATION_LAYOUT]);
+}
+
 /**
  * adw_header_bar_get_centering_policy: (attributes org.gtk.Method.get_property=centering-policy)
  * @self: a header bar
