@@ -129,6 +129,35 @@ strip_mnemonic (const char *src)
   return new_str;
 }
 
+static char *
+make_comparable (const char        *src,
+                 AdwPreferencesRow *row,
+                 gboolean           allow_underline)
+{
+  char *plaintext = g_utf8_casefold (src, -1);
+  GError *error = NULL;
+
+  if (adw_preferences_row_get_use_markup (row)) {
+    char *parsed = NULL;
+
+    if (pango_parse_markup (plaintext, -1, 0, NULL, &parsed, NULL, &error)) {
+      g_free (plaintext);
+      plaintext = parsed;
+    } else {
+      g_critical ("Couldn't parse markup: %s", error->message);
+      g_clear_error (&error);
+    }
+  }
+
+  if (allow_underline && adw_preferences_row_get_use_underline (row)) {
+    char *comparable = strip_mnemonic (plaintext);
+    g_free (plaintext);
+    return comparable;
+  }
+
+  return plaintext;
+}
+
 static gboolean
 filter_search_results (AdwPreferencesRow    *row,
                        AdwPreferencesWindow *self)
@@ -140,22 +169,12 @@ filter_search_results (AdwPreferencesRow    *row,
   g_assert (ADW_IS_PREFERENCES_ROW (row));
 
   terms = g_utf8_casefold (gtk_editable_get_text (GTK_EDITABLE (priv->search_entry)), -1);
-  title = g_utf8_casefold (adw_preferences_row_get_title (row), -1);
-
-  if (adw_preferences_row_get_use_underline (ADW_PREFERENCES_ROW (row))) {
-    char *stripped_title = strip_mnemonic (title);
-
-    if (stripped_title) {
-      g_free (title);
-
-      title = stripped_title;
-    }
-  }
+  title = make_comparable (adw_preferences_row_get_title (row), row, TRUE);
 
   if (!!strstr (title, terms)) {
     result = TRUE;
   } else if (ADW_IS_ACTION_ROW (row)) {
-    char *subtitle = g_utf8_casefold (adw_action_row_get_subtitle (ADW_ACTION_ROW (row)), -1);
+    char *subtitle = make_comparable (adw_action_row_get_subtitle (ADW_ACTION_ROW(row)), row, FALSE);
 
     if (!!strstr (subtitle, terms))
       result = TRUE;
@@ -541,11 +560,9 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * Since: 1.0
    */
   props[PROP_VISIBLE_PAGE] =
-      g_param_spec_object ("visible-page",
-                           "Visible page",
-                           "The currently visible page",
-                           GTK_TYPE_WIDGET,
-                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_object ("visible-page", NULL, NULL,
+                         GTK_TYPE_WIDGET,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStack:visible-page-name: (attributes org.gtk.Property.get=adw_preferences_window_get_visible_page_name org.gtk.Property.set=adw_preferences_window_set_visible_page_name)
@@ -557,11 +574,9 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * Since: 1.0
    */
   props[PROP_VISIBLE_PAGE_NAME] =
-      g_param_spec_string ("visible-page-name",
-                           "Name of visible page",
-                           "The name of the currently visible page",
-                           NULL,
-                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_string ("visible-page-name", NULL, NULL,
+                         NULL,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwPreferencesWindow:search-enabled: (attributes org.gtk.Property.get=adw_preferences_window_get_search_enabled org.gtk.Property.set=adw_preferences_window_set_search_enabled)
@@ -571,9 +586,7 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * Since: 1.0
    */
   props[PROP_SEARCH_ENABLED] =
-    g_param_spec_boolean ("search-enabled",
-                          "Search enabled",
-                          "Whether search is enabled",
+    g_param_spec_boolean ("search-enabled", NULL, NULL,
                           TRUE,
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -596,11 +609,9 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    * Since: 1.0
    */
   props[PROP_CAN_NAVIGATE_BACK] =
-      g_param_spec_boolean ("can-navigate-back",
-                            "Can navigate back",
-                            "Whether gestures and shortcuts for closing subpages are enabled",
-                            FALSE,
-                            G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_boolean ("can-navigate-back", NULL, NULL,
+                          FALSE,
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -636,12 +647,11 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, stop_search_cb);
 }
 
-static GListModel *
-preferences_page_to_rows (AdwViewStackPage *page)
+static gpointer
+preferences_page_to_rows (gpointer page,
+                          gpointer user_data)
 {
-  GtkWidget *child = adw_view_stack_page_get_child (page);
-
-  g_object_unref (page);
+  GtkWidget *child = adw_view_stack_page_get_child (ADW_VIEW_STACK_PAGE (page));
 
   return adw_preferences_page_get_rows (ADW_PREFERENCES_PAGE (child));
 }
@@ -662,10 +672,7 @@ adw_preferences_window_init (AdwPreferencesWindow *self)
 
   model = G_LIST_MODEL (adw_view_stack_get_pages (priv->pages_stack));
   model = G_LIST_MODEL (gtk_filter_list_model_new (model, GTK_FILTER (gtk_bool_filter_new (expr))));
-  model = G_LIST_MODEL (gtk_map_list_model_new (model,
-                                                (GtkMapListModelMapFunc) preferences_page_to_rows,
-                                                NULL,
-                                                NULL));
+  model = G_LIST_MODEL (gtk_map_list_model_new (model, preferences_page_to_rows, NULL, NULL));
   model = G_LIST_MODEL (gtk_flatten_list_model_new (model));
   priv->filter_model = gtk_filter_list_model_new (model, priv->filter);
 
@@ -711,177 +718,6 @@ adw_preferences_window_new (void)
   return g_object_new (ADW_TYPE_PREFERENCES_WINDOW, NULL);
 }
 
-/**
- * adw_preferences_window_get_search_enabled: (attributes org.gtk.Method.get_property=search-enabled)
- * @self: a preferences window
- *
- * Gets whether search is enabled for @self.
- *
- * Returns: whether search is enabled for @self.
- *
- * Since: 1.0
- */
-gboolean
-adw_preferences_window_get_search_enabled (AdwPreferencesWindow *self)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_WINDOW (self), FALSE);
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  return priv->search_enabled;
-}
-
-/**
- * adw_preferences_window_set_search_enabled: (attributes org.gtk.Method.set_property=search-enabled)
- * @self: a preferences window
- * @search_enabled: whether search is enabled
- *
- * Sets whether search is enabled for @self.
- *
- * Since: 1.0
- */
-void
-adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
-                                           gboolean              search_enabled)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  search_enabled = !!search_enabled;
-
-  if (priv->search_enabled == search_enabled)
-    return;
-
-  priv->search_enabled = search_enabled;
-  gtk_widget_set_visible (GTK_WIDGET (priv->search_button), search_enabled);
-  if (search_enabled) {
-    gtk_search_entry_set_key_capture_widget (priv->search_entry, GTK_WIDGET (self));
-  } else {
-    gtk_toggle_button_set_active (priv->search_button, FALSE);
-    gtk_search_entry_set_key_capture_widget (priv->search_entry, NULL);
-  }
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SEARCH_ENABLED]);
-}
-
-/**
- * adw_preferences_window_set_can_navigate_back: (attributes org.gtk.Method.set_property=can-navigate-back)
- * @self: a preferences window
- * @can_navigate_back: the new value
- *
- * Sets whether gestures and shortcuts for closing subpages are enabled.
- *
- * Since: 1.0
- */
-void
-adw_preferences_window_set_can_navigate_back (AdwPreferencesWindow *self,
-                                              gboolean              can_navigate_back)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  can_navigate_back = !!can_navigate_back;
-
-  if (priv->can_navigate_back == can_navigate_back)
-    return;
-
-  priv->can_navigate_back = can_navigate_back;
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CAN_NAVIGATE_BACK]);
-}
-
-/**
- * adw_preferences_window_get_can_navigate_back: (attributes org.gtk.Method.get_property=can-navigate-back)
- * @self: a preferences window
- *
- * Gets whether gestures and shortcuts for closing subpages are enabled.
- *
- * Returns: whether gestures and shortcuts are enabled.
- *
- * Since: 1.0
- */
-gboolean
-adw_preferences_window_get_can_navigate_back (AdwPreferencesWindow *self)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_WINDOW (self), FALSE);
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  return priv->can_navigate_back;
-}
-
-/**
- * adw_preferences_window_present_subpage:
- * @self: a preferences window
- * @subpage: the subpage
- *
- * Sets @subpage as the window's subpage and opens it.
- *
- * The transition can be cancelled by the user, in which case visible child will
- * change back to the previously visible child.
- *
- * Since: 1.0
- */
-void
-adw_preferences_window_present_subpage (AdwPreferencesWindow *self,
-                                        GtkWidget            *subpage)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
-  g_return_if_fail (GTK_IS_WIDGET (subpage));
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  if (priv->subpage == subpage)
-    return;
-
-  priv->subpage = subpage;
-
-  /* The check below avoids a warning when re-entering a subpage during the
-   * transition between the that subpage to the preferences.
-   */
-  if (gtk_widget_get_parent (subpage) != GTK_WIDGET (priv->subpages_leaflet))
-    adw_leaflet_append (priv->subpages_leaflet, subpage);
-
-  adw_leaflet_set_visible_child (priv->subpages_leaflet, subpage);
-}
-
-/**
- * adw_preferences_window_close_subpage:
- * @self: a preferences window
- *
- * Closes the current subpage.
- *
- * If there is no presented subpage, this does nothing.
- *
- * Since: 1.0
- */
-void
-adw_preferences_window_close_subpage (AdwPreferencesWindow *self)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  if (priv->subpage == NULL)
-    return;
-
-  adw_leaflet_set_visible_child (priv->subpages_leaflet, priv->preferences);
-}
-
 /**
  * adw_preferences_window_add:
  * @self: a preferences window
@@ -1011,6 +847,8 @@ adw_preferences_window_get_visible_page_name (AdwPreferencesWindow *self)
  *
  * Makes the page with the given name visible.
  *
+ * See [property@ViewStack:visible-child].
+ *
  * Since: 1.0
  */
 void
@@ -1026,6 +864,188 @@ adw_preferences_window_set_visible_page_name (AdwPreferencesWindow *self,
   adw_view_stack_set_visible_child_name (priv->pages_stack, name);
 }
 
+/**
+ * adw_preferences_window_get_search_enabled: (attributes org.gtk.Method.get_property=search-enabled)
+ * @self: a preferences window
+ *
+ * Gets whether search is enabled for @self.
+ *
+ * Returns: whether search is enabled for @self.
+ *
+ * Since: 1.0
+ */
+gboolean
+adw_preferences_window_get_search_enabled (AdwPreferencesWindow *self)
+{
+  AdwPreferencesWindowPrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_WINDOW (self), FALSE);
+
+  priv = adw_preferences_window_get_instance_private (self);
+
+  return priv->search_enabled;
+}
+
+/**
+ * adw_preferences_window_set_search_enabled: (attributes org.gtk.Method.set_property=search-enabled)
+ * @self: a preferences window
+ * @search_enabled: whether search is enabled
+ *
+ * Sets whether search is enabled for @self.
+ *
+ * Since: 1.0
+ */
+void
+adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
+                                           gboolean              search_enabled)
+{
+  AdwPreferencesWindowPrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
+
+  priv = adw_preferences_window_get_instance_private (self);
+
+  search_enabled = !!search_enabled;
+
+  if (priv->search_enabled == search_enabled)
+    return;
+
+  priv->search_enabled = search_enabled;
+  gtk_widget_set_visible (GTK_WIDGET (priv->search_button), search_enabled);
+  if (search_enabled) {
+    gtk_search_entry_set_key_capture_widget (priv->search_entry, GTK_WIDGET (self));
+  } else {
+    gtk_toggle_button_set_active (priv->search_button, FALSE);
+    gtk_search_entry_set_key_capture_widget (priv->search_entry, NULL);
+  }
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SEARCH_ENABLED]);
+}
+
+/**
+ * adw_preferences_window_set_can_navigate_back: (attributes org.gtk.Method.set_property=can-navigate-back)
+ * @self: a preferences window
+ * @can_navigate_back: the new value
+ *
+ * Sets whether gestures and shortcuts for closing subpages are enabled.
+ *
+ * The supported gestures are:
+ *
+ * - One-finger swipe on touchscreens
+ * - Horizontal scrolling on touchpads (usually two-finger swipe)
+ * - Back mouse button
+ *
+ * The keyboard back key is also supported, as well as the
+ * <kbd>Alt</kbd>+<kbd>←</kbd> shortcut.
+ *
+ * For right-to-left locales, gestures and shortcuts are reversed.
+ *
+ * Since: 1.0
+ */
+void
+adw_preferences_window_set_can_navigate_back (AdwPreferencesWindow *self,
+                                              gboolean              can_navigate_back)
+{
+  AdwPreferencesWindowPrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
+
+  priv = adw_preferences_window_get_instance_private (self);
+
+  can_navigate_back = !!can_navigate_back;
+
+  if (priv->can_navigate_back == can_navigate_back)
+    return;
+
+  priv->can_navigate_back = can_navigate_back;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_CAN_NAVIGATE_BACK]);
+}
+
+/**
+ * adw_preferences_window_get_can_navigate_back: (attributes org.gtk.Method.get_property=can-navigate-back)
+ * @self: a preferences window
+ *
+ * Gets whether gestures and shortcuts for closing subpages are enabled.
+ *
+ * Returns: whether gestures and shortcuts are enabled.
+ *
+ * Since: 1.0
+ */
+gboolean
+adw_preferences_window_get_can_navigate_back (AdwPreferencesWindow *self)
+{
+  AdwPreferencesWindowPrivate *priv;
+
+  g_return_val_if_fail (ADW_IS_PREFERENCES_WINDOW (self), FALSE);
+
+  priv = adw_preferences_window_get_instance_private (self);
+
+  return priv->can_navigate_back;
+}
+
+/**
+ * adw_preferences_window_present_subpage:
+ * @self: a preferences window
+ * @subpage: the subpage
+ *
+ * Sets @subpage as the window's subpage and opens it.
+ *
+ * The transition can be cancelled by the user, in which case visible child will
+ * change back to the previously visible child.
+ *
+ * Since: 1.0
+ */
+void
+adw_preferences_window_present_subpage (AdwPreferencesWindow *self,
+                                        GtkWidget            *subpage)
+{
+  AdwPreferencesWindowPrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
+  g_return_if_fail (GTK_IS_WIDGET (subpage));
+
+  priv = adw_preferences_window_get_instance_private (self);
+
+  if (priv->subpage == subpage)
+    return;
+
+  priv->subpage = subpage;
+
+  /* The check below avoids a warning when re-entering a subpage during the
+   * transition between the that subpage to the preferences.
+   */
+  if (gtk_widget_get_parent (subpage) != GTK_WIDGET (priv->subpages_leaflet))
+    adw_leaflet_append (priv->subpages_leaflet, subpage);
+
+  adw_leaflet_set_visible_child (priv->subpages_leaflet, subpage);
+}
+
+/**
+ * adw_preferences_window_close_subpage:
+ * @self: a preferences window
+ *
+ * Closes the current subpage.
+ *
+ * If there is no presented subpage, this does nothing.
+ *
+ * Since: 1.0
+ */
+void
+adw_preferences_window_close_subpage (AdwPreferencesWindow *self)
+{
+  AdwPreferencesWindowPrivate *priv;
+
+  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
+
+  priv = adw_preferences_window_get_instance_private (self);
+
+  if (priv->subpage == NULL)
+    return;
+
+  adw_leaflet_set_visible_child (priv->subpages_leaflet, priv->preferences);
+}
+
 /**
  * adw_preferences_window_add_toast:
  * @self: a preferences window
