@@ -63,6 +63,7 @@ enum {
   PROP_MENU_MODEL,
   PROP_POPOVER,
   PROP_DIRECTION,
+  PROP_DROPDOWN_TOOLTIP,
 
   /* actionable properties */
   PROP_ACTION_NAME,
@@ -192,6 +193,9 @@ adw_split_button_get_property (GObject    *object,
   case PROP_DIRECTION:
     g_value_set_enum (value, adw_split_button_get_direction (self));
     break;
+  case PROP_DROPDOWN_TOOLTIP:
+    g_value_set_string (value, adw_split_button_get_dropdown_tooltip (self));
+    break;
   case PROP_ACTION_NAME:
     g_value_set_string (value, gtk_actionable_get_action_name (GTK_ACTIONABLE (self)));
     break;
@@ -234,6 +238,9 @@ adw_split_button_set_property (GObject      *object,
   case PROP_DIRECTION:
     adw_split_button_set_direction (self, g_value_get_enum (value));
     break;
+  case PROP_DROPDOWN_TOOLTIP:
+    adw_split_button_set_dropdown_tooltip (self, g_value_get_string (value));
+    break;
   case PROP_ACTION_NAME:
     gtk_actionable_set_action_name (GTK_ACTIONABLE (self), g_value_get_string (value));
     break;
@@ -285,11 +292,9 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * Since: 1.0
    */
   props[PROP_LABEL] =
-    g_param_spec_string ("label",
-                         "Label",
-                         "The label for the button",
+    g_param_spec_string ("label", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSplitButton:use-underline: (attributes org.gtk.Property.get=adw_split_button_get_use_underline org.gtk.Property.set=adw_split_button_set_use_underline)
@@ -301,11 +306,9 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * Since: 1.0
    */
   props[PROP_USE_UNDERLINE] =
-    g_param_spec_boolean ("use-underline",
-                          "Use underline",
-                          "Whether an underline in the text indicates a mnemonic",
+    g_param_spec_boolean ("use-underline", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSplitButton:icon-name: (attributes org.gtk.Property.get=adw_split_button_get_icon_name org.gtk.Property.set=adw_split_button_set_icon_name)
@@ -318,11 +321,9 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * Since: 1.0
    */
   props[PROP_ICON_NAME] =
-    g_param_spec_string ("icon-name",
-                         "Icon Name",
-                         "The name of the icon used to automatically populate the button",
+    g_param_spec_string ("icon-name", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSplitButton:child: (attributes org.gtk.Property.get=adw_split_button_get_child org.gtk.Property.set=adw_split_button_set_child)
@@ -335,11 +336,9 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * Since: 1.0
    */
   props[PROP_CHILD] =
-    g_param_spec_object ("child",
-                         "Child",
-                         "The child widget",
+    g_param_spec_object ("child", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSplitButton:menu-model: (attributes org.gtk.Property.get=adw_split_button_get_menu_model org.gtk.Property.set=adw_split_button_set_menu_model)
@@ -349,8 +348,8 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * If the menu model is `NULL`, the dropdown is disabled.
    *
    * A [class@Gtk.Popover] will be created from the menu model with
-   * [ctor@Gtk.PopoverMenu.new_from_model]. Actions will be connected
-   * as documented for this function.
+   * [ctor@Gtk.PopoverMenu.new_from_model]. Actions will be connected as
+   * documented for this function.
    *
    * If [property@SplitButton:popover] is already set, it will be dissociated
    * from the button, and the property is set to `NULL`.
@@ -358,11 +357,9 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * Since: 1.0
    */
   props[PROP_MENU_MODEL] =
-    g_param_spec_object ("menu-model",
-                         "Menu model",
-                         "The model from which the popup is made",
+    g_param_spec_object ("menu-model", NULL, NULL,
                          G_TYPE_MENU_MODEL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSplitButton:popover: (attributes org.gtk.Property.get=adw_split_button_get_popover org.gtk.Property.set=adw_split_button_set_popover)
@@ -377,11 +374,9 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    * Since: 1.0
    */
   props[PROP_POPOVER] =
-    g_param_spec_object ("popover",
-                         "Popover",
-                         "The popover that will be popped up when the dropdown is clicked",
+    g_param_spec_object ("popover", NULL, NULL,
                          GTK_TYPE_POPOVER,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSplitButton:direction: (attributes org.gtk.Property.get=adw_split_button_get_direction org.gtk.Property.set=adw_split_button_set_direction)
@@ -390,20 +385,32 @@ adw_split_button_class_init (AdwSplitButtonClass *klass)
    *
    * The dropdown arrow icon will point at the same direction.
    *
-   * If the does not fit in the available space in the given direction,
-   * GTK will its best to keep it inside the screen and fully visible.
+   * If the does not fit in the available space in the given direction, GTK will
+   * try its best to keep it inside the screen and fully visible.
    *
    * If you pass `GTK_ARROW_NONE`, it's equivalent to `GTK_ARROW_DOWN`.
    *
    * Since: 1.0
    */
   props[PROP_DIRECTION] =
-    g_param_spec_enum ("direction",
-                       "Direction",
-                       "The direction in which the popup will be popped up",
+    g_param_spec_enum ("direction", NULL, NULL,
                        GTK_TYPE_ARROW_TYPE,
                        GTK_ARROW_DOWN,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
+  /**
+   * AdwSplitButton:dropdown-tooltip: (attributes org.gtk.Property.get=adw_split_button_get_dropdown_tooltip org.gtk.Property.set=adw_split_button_set_dropdown_tooltip)
+   *
+   * The tooltip of the dropdown button.
+   *
+   * The tooltip can be marked up with the Pango text markup language.
+   *
+   * Since: 1.2
+   */
+  props[PROP_DROPDOWN_TOOLTIP] =
+    g_param_spec_string ("dropdown-tooltip", NULL, NULL,
+                         "",
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -617,6 +624,9 @@ adw_split_button_get_label (AdwSplitButton *self)
  *
  * Sets the label for @self.
  *
+ * Setting the label will set [property@SplitButton:icon-name] and
+ * [property@SplitButton:child] to `NULL`.
+ *
  * Since: 1.0
  */
 void
@@ -667,6 +677,8 @@ adw_split_button_get_use_underline (AdwSplitButton *self)
  *
  * Sets whether an underline in the text indicates a mnemonic.
  *
+ * See [property@SplitButton:label].
+ *
  * Since: 1.0
  */
 void
@@ -689,9 +701,6 @@ adw_split_button_set_use_underline (AdwSplitButton *self,
  *
  * Gets the name of the icon used to automatically populate the button.
  *
- * If the icon name has not been set with [method@SplitButton.set_icon_name]
- * the return value will be `NULL`.
- *
  * Returns: (nullable): the icon name
  *
  * Since: 1.0
@@ -711,6 +720,9 @@ adw_split_button_get_icon_name (AdwSplitButton *self)
  *
  * Sets the name of the icon used to automatically populate the button.
  *
+ * Setting the icon name will set [property@SplitButton:label] and
+ * [property@SplitButton:child] to `NULL`.
+ *
  * Since: 1.0
  */
 void
@@ -762,6 +774,9 @@ adw_split_button_get_child (AdwSplitButton *self)
  *
  * Sets the child widget.
  *
+ * Setting the child widget will set [property@SplitButton:label] and
+ * [property@SplitButton:icon-name] to `NULL`.
+ *
  * Since: 1.0
  */
 void
@@ -812,6 +827,15 @@ adw_split_button_get_menu_model (AdwSplitButton *self)
  *
  * Sets the menu model from which the popup will be created.
  *
+ * If the menu model is `NULL`, the dropdown is disabled.
+ *
+ * A [class@Gtk.Popover] will be created from the menu model with
+ * [ctor@Gtk.PopoverMenu.new_from_model]. Actions will be connected as
+ * documented for this function.
+ *
+ * If [property@SplitButton:popover] is already set, it will be dissociated from
+ * the button, and the property is set to `NULL`.
+ *
  * Since: 1.0
  */
 void
@@ -851,6 +875,11 @@ adw_split_button_get_popover (AdwSplitButton *self)
  *
  * Sets the popover that will be popped up when the dropdown is clicked.
  *
+ * If the popover is `NULL`, the dropdown is disabled.
+ *
+ * If [property@SplitButton:menu-model] is set, the menu model is dissociated
+ * from the button, and the property is set to `NULL`.
+ *
  * Since: 1.0
  */
 void
@@ -890,6 +919,13 @@ adw_split_button_get_direction (AdwSplitButton *self)
  *
  * Sets the direction in which the popup will be popped up.
  *
+ * The dropdown arrow icon will point at the same direction.
+ *
+ * If the does not fit in the available space in the given direction, GTK will
+ * try its best to keep it inside the screen and fully visible.
+ *
+ * If you pass `GTK_ARROW_NONE`, it's equivalent to `GTK_ARROW_DOWN`.
+ *
  * Since: 1.0
  */
 void
@@ -906,6 +942,54 @@ adw_split_button_set_direction (AdwSplitButton *self,
   update_style_classes (self);
 }
 
+/**
+ * adw_split_button_get_dropdown_tooltip: (attributes org.gtk.Method.get_property=dropdown-tooltip)
+ * @self: a split button
+ *
+ * Gets the tooltip of the dropdown button of @self.
+ *
+ * Returns: (transfer none): the dropdown tooltip of @self
+ *
+ * Since: 1.2
+ */
+const char *
+adw_split_button_get_dropdown_tooltip (AdwSplitButton *self)
+{
+  const char *tooltip;
+
+  g_return_val_if_fail (ADW_IS_SPLIT_BUTTON (self), NULL);
+
+  tooltip = gtk_widget_get_tooltip_markup (self->menu_button);
+
+  return tooltip ? tooltip : "";
+}
+
+/**
+ * adw_split_button_set_dropdown_tooltip: (attributes org.gtk.Method.set_property=dropdown-tooltip)
+ * @self: a split button
+ * @tooltip: the dropdown tooltip of @self
+ *
+ * Sets the tooltip of the dropdown button of @self.
+ *
+ * The tooltip can be marked up with the Pango text markup language.
+ *
+ * Since: 1.2
+ */
+void
+adw_split_button_set_dropdown_tooltip (AdwSplitButton *self,
+                                       const char     *tooltip)
+{
+  g_return_if_fail (ADW_IS_SPLIT_BUTTON (self));
+  g_return_if_fail (tooltip != NULL);
+
+  if (!g_strcmp0 (tooltip, adw_split_button_get_dropdown_tooltip (self)))
+    return;
+
+  gtk_widget_set_tooltip_markup (self->menu_button, tooltip);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_DROPDOWN_TOOLTIP]);
+}
+
 /**
  * adw_split_button_popup:
  * @self: a split button
