@@ -123,9 +123,9 @@ struct _AdwSqueezer
 
 enum  {
   PROP_0,
+  PROP_VISIBLE_CHILD,
   PROP_HOMOGENEOUS,
   PROP_SWITCH_THRESHOLD_POLICY,
-  PROP_VISIBLE_CHILD,
   PROP_ALLOW_NONE,
   PROP_TRANSITION_DURATION,
   PROP_TRANSITION_TYPE,
@@ -219,16 +219,14 @@ adw_squeezer_page_class_init (AdwSqueezerPageClass *klass)
   /**
    * AdwSqueezerPage:child: (attributes org.gtk.Property.get=adw_squeezer_page_get_child)
    *
-   * The child of the page.
+   * The the squeezer child to which the page belongs.
    *
    * Since: 1.0
    */
   page_props[PAGE_PROP_CHILD] =
-    g_param_spec_object ("child",
-                         "Child",
-                         "The child of the page",
+    g_param_spec_object ("child", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwSqueezerPage:enabled: (attributes org.gtk.Property.get=adw_squeezer_page_get_enabled org.gtk.Property.set=adw_squeezer_page_set_enabled)
@@ -247,11 +245,9 @@ adw_squeezer_page_class_init (AdwSqueezerPageClass *klass)
    * Since: 1.0
    */
   page_props[PAGE_PROP_ENABLED] =
-    g_param_spec_boolean ("enabled",
-                          "Enabled",
-                          "Whether the child is enabled",
+    g_param_spec_boolean ("enabled", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PAGE_PROP, page_props);
 }
@@ -654,15 +650,15 @@ adw_squeezer_get_property (GObject    *object,
   AdwSqueezer *self = ADW_SQUEEZER (object);
 
   switch (property_id) {
+  case PROP_VISIBLE_CHILD:
+    g_value_set_object (value, adw_squeezer_get_visible_child (self));
+    break;
   case PROP_HOMOGENEOUS:
     g_value_set_boolean (value, adw_squeezer_get_homogeneous (self));
     break;
   case PROP_SWITCH_THRESHOLD_POLICY:
     g_value_set_enum (value, adw_squeezer_get_switch_threshold_policy (self));
     break;
-  case PROP_VISIBLE_CHILD:
-    g_value_set_object (value, adw_squeezer_get_visible_child (self));
-    break;
   case PROP_ALLOW_NONE:
     g_value_set_boolean (value, adw_squeezer_get_allow_none (self));
     break;
@@ -822,17 +818,13 @@ adw_squeezer_size_allocate (GtkWidget *widget,
     if (!page->enabled)
       continue;
 
-    if (self->orientation == GTK_ORIENTATION_VERTICAL) {
+    if (self->orientation == GTK_ORIENTATION_VERTICAL)
       compare_size = height;
-
-      gtk_widget_measure (child, self->orientation, -1,
-                          &child_min, &child_nat, NULL, NULL);
-    } else {
+    else
       compare_size = width;
 
-      gtk_widget_measure (child, self->orientation, -1,
-                          &child_min, &child_nat, NULL, NULL);
-    }
+    gtk_widget_measure (child, self->orientation, -1,
+                        &child_min, &child_nat, NULL, NULL);
 
     if (child_min <= compare_size && self->switch_threshold_policy == ADW_FOLD_THRESHOLD_POLICY_MINIMUM)
       break;
@@ -1046,47 +1038,6 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                                     PROP_ORIENTATION,
                                     "orientation");
 
-  /**
-   * AdwSqueezer:homogeneous: (attributes org.gtk.Property.get=adw_squeezer_get_homogeneous org.gtk.Property.set=adw_squeezer_set_homogeneous)
-   *
-   * Whether all children have the same size for the opposite orientation.
-   *
-   * For example, if a squeezer is horizontal and is homogeneous, it will request
-   * the same height for all its children. If it isn't, the squeezer may change
-   * size when a different child becomes visible.
-   *
-   * Since: 1.0
-   */
-  props[PROP_HOMOGENEOUS] =
-    g_param_spec_boolean ("homogeneous",
-                          "Homogeneous",
-                          "Whether all children have the same size for the opposite orientation",
-                          FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * AdwSqueezer:switch-threshold-policy: (attributes org.gtk.Property.get=adw_squeezer_get_switch_threshold_policy org.gtk.Property.set=adw_squeezer_set_switch_threshold_policy)
-   *
-   * Determines when the squeezer will switch children.
-   *
-   * If set to `ADW_FOLD_THRESHOLD_POLICY_MINIMUM`, it will only switch when
-   * the visible child cannot fit anymore. With
-   * `ADW_FOLD_THRESHOLD_POLICY_NATURAL`, it will switch as soon as the visible
-   * child doesn't get their natural size.
-   *
-   * This can be useful if you have a long ellipsizing label and want to let it
-   * ellipsize instead of immediately switching.
-   *
-   * Since: 1.0
-   */
-  props[PROP_SWITCH_THRESHOLD_POLICY] =
-    g_param_spec_enum ("switch-threshold-policy",
-                       "Switch Threshold Policy",
-                       "Determines when the leaflet will fold",
-                       ADW_TYPE_FOLD_THRESHOLD_POLICY,
-                       ADW_FOLD_THRESHOLD_POLICY_NATURAL,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
   /**
    * AdwSqueezer:visible-child: (attributes org.gtk.Property.get=adw_squeezer_get_visible_child)
    *
@@ -1095,11 +1046,47 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_VISIBLE_CHILD] =
-    g_param_spec_object ("visible-child",
-                         "Visible child",
-                         "The currently visible child",
+    g_param_spec_object ("visible-child", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
+  /**
+   * AdwSqueezer:homogeneous: (attributes org.gtk.Property.get=adw_squeezer_get_homogeneous org.gtk.Property.set=adw_squeezer_set_homogeneous)
+   *
+   * Whether all children have the same size for the opposite orientation.
+   *
+   * For example, if a squeezer is horizontal and is homogeneous, it will
+   * request the same height for all its children. If it isn't, the squeezer may
+   * change size when a different child becomes visible.
+   *
+   * Since: 1.0
+   */
+  props[PROP_HOMOGENEOUS] =
+    g_param_spec_boolean ("homogeneous", NULL, NULL,
+                          FALSE,
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
+  /**
+   * AdwSqueezer:switch-threshold-policy: (attributes org.gtk.Property.get=adw_squeezer_get_switch_threshold_policy org.gtk.Property.set=adw_squeezer_set_switch_threshold_policy)
+   *
+   * The switch threshold policy.
+   *
+   * Determines when the squeezer will switch children.
+   *
+   * If set to `ADW_FOLD_THRESHOLD_POLICY_MINIMUM`, it will only switch when the
+   * visible child cannot fit anymore. With `ADW_FOLD_THRESHOLD_POLICY_NATURAL`,
+   * it will switch as soon as the visible child doesn't get their natural size.
+   *
+   * This can be useful if you have a long ellipsizing label and want to let it
+   * ellipsize instead of immediately switching.
+   *
+   * Since: 1.0
+   */
+  props[PROP_SWITCH_THRESHOLD_POLICY] =
+    g_param_spec_enum ("switch-threshold-policy", NULL, NULL,
+                       ADW_TYPE_FOLD_THRESHOLD_POLICY,
+                       ADW_FOLD_THRESHOLD_POLICY_NATURAL,
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:allow-none: (attributes org.gtk.Property.get=adw_squeezer_get_allow_none org.gtk.Property.set=adw_squeezer_set_allow_none)
@@ -1107,31 +1094,27 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Whether to allow squeezing beyond the last child's minimum size.
    *
    * If set to `TRUE`, the squeezer can shrink to the point where no child can
-   * be shown. This is functionally equivalent to appending a widget with 0x0
+   * be shown. This is functionally equivalent to appending a widget with 0×0
    * minimum size.
    *
    * Since: 1.0
    */
   props[PROP_ALLOW_NONE] =
-    g_param_spec_boolean ("allow-none",
-                          "Allow none",
-                          "Whether to allow squeezing beyond the last child's minimum size",
+    g_param_spec_boolean ("allow-none", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:transition-duration: (attributes org.gtk.Property.get=adw_squeezer_get_transition_duration org.gtk.Property.set=adw_squeezer_set_transition_duration)
    *
-   * The animation duration, in milliseconds.
+   * The transition animation duration, in milliseconds.
    *
    * Since: 1.0
    */
   props[PROP_TRANSITION_DURATION] =
-    g_param_spec_uint ("transition-duration",
-                       "Transition duration",
-                       "The animation duration, in milliseconds",
+    g_param_spec_uint ("transition-duration", NULL, NULL,
                        0, G_MAXUINT, 200,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:transition-type: (attributes org.gtk.Property.get=adw_squeezer_get_transition_type org.gtk.Property.set=adw_squeezer_set_transition_type)
@@ -1141,12 +1124,10 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_TRANSITION_TYPE] =
-    g_param_spec_enum ("transition-type",
-                       "Transition type",
-                       "The type of animation used for transitions between children",
+    g_param_spec_enum ("transition-type", NULL, NULL,
                        ADW_TYPE_SQUEEZER_TRANSITION_TYPE,
                        ADW_SQUEEZER_TRANSITION_TYPE_NONE,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:transition-running: (attributes org.gtk.Property.get=adw_squeezer_get_transition_running)
@@ -1160,11 +1141,9 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_TRANSITION_RUNNING] =
-    g_param_spec_boolean ("transition-running",
-                          "Transition running",
-                          "Whether a transition is currently running",
+    g_param_spec_boolean ("transition-running", NULL, NULL,
                           FALSE,
-                          G_PARAM_READABLE);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwSqueezer:interpolate-size: (attributes org.gtk.Property.get=adw_squeezer_get_interpolate_size org.gtk.Property.set=adw_squeezer_set_interpolate_size)
@@ -1179,11 +1158,9 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_INTERPOLATE_SIZE] =
-    g_param_spec_boolean ("interpolate-size",
-                          "Interpolate size",
-                          "Whether the squeezer interpolates its size when changing the visible child",
+    g_param_spec_boolean ("interpolate-size", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:xalign: (attributes org.gtk.Property.get=adw_squeezer_get_xalign org.gtk.Property.set=adw_squeezer_set_xalign)
@@ -1199,12 +1176,10 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_XALIGN] =
-    g_param_spec_float ("xalign",
-                        "X align",
-                        "The horizontal alignment, from 0 (start) to 1 (end)",
+    g_param_spec_float ("xalign", NULL, NULL,
                         0.0, 1.0,
                         0.5,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:yalign: (attributes org.gtk.Property.get=adw_squeezer_get_yalign org.gtk.Property.set=adw_squeezer_set_yalign)
@@ -1220,12 +1195,10 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_YALIGN] =
-    g_param_spec_float ("yalign",
-                        "Y align",
-                        "The vertical alignment, from 0 (top) to 1 (bottom)",
+    g_param_spec_float ("yalign", NULL, NULL,
                         0.0, 1.0,
                         0.5,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwSqueezer:pages: (attributes org.gtk.Property.get=adw_squeezer_get_pages)
@@ -1238,11 +1211,9 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
    * Since: 1.0
    */
   props[PROP_PAGES] =
-    g_param_spec_object ("pages",
-                         "Pages",
-                         "A selection model with the squeezer's pages",
+    g_param_spec_object ("pages", NULL, NULL,
                          GTK_TYPE_SELECTION_MODEL,
-                         G_PARAM_READABLE);
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -1336,6 +1307,15 @@ adw_squeezer_page_get_enabled (AdwSqueezerPage *self)
  *
  * Sets whether @self is enabled.
  *
+ * If a child is disabled, it will be ignored when looking for the child
+ * fitting the available size best.
+ *
+ * This allows to programmatically and prematurely hide a child even if it fits
+ * in the available space.
+ *
+ * This can be used e.g. to ensure a certain child is hidden below a certain
+ * window width, or any other constraint you find suitable.
+ *
  * Since: 1.0
  */
 void
@@ -1460,6 +1440,24 @@ adw_squeezer_get_page (AdwSqueezer *self,
   return find_page_for_widget (self, child);
 }
 
+/**
+ * adw_squeezer_get_visible_child: (attributes org.gtk.Method.get_property=visible-child)
+ * @self: a squeezer
+ *
+ * Gets the currently visible child of @self.
+ *
+ * Returns: (transfer none) (nullable): the visible child
+ *
+ * Since: 1.0
+ */
+GtkWidget *
+adw_squeezer_get_visible_child (AdwSqueezer *self)
+{
+  g_return_val_if_fail (ADW_IS_SQUEEZER (self), NULL);
+
+  return self->visible_child ? self->visible_child->widget : NULL;
+}
+
 /**
  * adw_squeezer_get_homogeneous: (attributes org.gtk.Method.get_property=homogeneous)
  * @self: a squeezer
@@ -1485,6 +1483,10 @@ adw_squeezer_get_homogeneous (AdwSqueezer *self)
  *
  * Sets whether all children have the same size for the opposite orientation.
  *
+ * For example, if a squeezer is horizontal and is homogeneous, it will request
+ * the same height for all its children. If it isn't, the squeezer may change
+ * size when a different child becomes visible.
+ *
  * Since: 1.0
  */
 void
@@ -1510,7 +1512,7 @@ adw_squeezer_set_homogeneous (AdwSqueezer *self,
  * adw_squeezer_get_switch_threshold_policy: (attributes org.gtk.Method.get_property=switch-threshold-policy)
  * @self: a squeezer
  *
- * Gets the fold threshold policy for @self.
+ * Gets the switch threshold policy for @self.
  *
  * Since: 1.0
  */
@@ -1528,7 +1530,16 @@ adw_squeezer_get_switch_threshold_policy (AdwSqueezer *self)
  * @self: a squeezer
  * @policy: the policy to use
  *
- * Sets the fold threshold policy for @self.
+ * Sets the switch threshold policy for @self.
+ *
+ * Determines when the squeezer will switch children.
+ *
+ * If set to `ADW_FOLD_THRESHOLD_POLICY_MINIMUM`, it will only switch when the
+ * visible child cannot fit anymore. With `ADW_FOLD_THRESHOLD_POLICY_NATURAL`,
+ * it will switch as soon as the visible child doesn't get their natural size.
+ *
+ * This can be useful if you have a long ellipsizing label and want to let it
+ * ellipsize instead of immediately switching.
  *
  * Since: 1.0
  */
@@ -1574,6 +1585,10 @@ adw_squeezer_get_allow_none (AdwSqueezer *self)
  *
  * Sets whether to allow squeezing beyond the last child's minimum size.
  *
+ * If set to `TRUE`, the squeezer can shrink to the point where no child can be
+ * shown. This is functionally equivalent to appending a widget with 0×0 minimum
+ * size.
+ *
  * Since: 1.0
  */
 void
@@ -1681,6 +1696,10 @@ adw_squeezer_set_transition_type (AdwSqueezer               *self,
  *
  * Gets whether a transition is currently running for @self.
  *
+ * If a transition is impossible, the property value will be set to `TRUE` and
+ * then immediately to `FALSE`, so it's possible to rely on its notifications
+ * to know that a transition has happened.
+ *
  * Returns: whether a transition is currently running
  *
  * Since: 1.0
@@ -1718,6 +1737,11 @@ adw_squeezer_get_interpolate_size (AdwSqueezer *self)
  *
  * Sets whether @self interpolates its size when changing the visible child.
  *
+ * If `TRUE`, the squeezer will interpolate its size between the one of the
+ * previous visible child and the one of the new visible child, according to the
+ * set transition duration and the orientation, e.g. if the squeezer is
+ * horizontal, it will interpolate the its height.
+ *
  * Since: 1.0
  */
 void
@@ -1735,24 +1759,6 @@ adw_squeezer_set_interpolate_size (AdwSqueezer *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_INTERPOLATE_SIZE]);
 }
 
-/**
- * adw_squeezer_get_visible_child: (attributes org.gtk.Method.get_property=visible-child)
- * @self: a squeezer
- *
- * Gets the currently visible child of @self.
- *
- * Returns: (transfer none) (nullable): the visible child
- *
- * Since: 1.0
- */
-GtkWidget *
-adw_squeezer_get_visible_child (AdwSqueezer *self)
-{
-  g_return_val_if_fail (ADW_IS_SQUEEZER (self), NULL);
-
-  return self->visible_child ? self->visible_child->widget : NULL;
-}
-
 /**
  * adw_squeezer_get_xalign: (attributes org.gtk.Method.get_property=xalign)
  * @self: a squeezer
@@ -1778,6 +1784,12 @@ adw_squeezer_get_xalign (AdwSqueezer *self)
  *
  * Sets the horizontal alignment, from 0 (start) to 1 (end).
  *
+ * This affects the children allocation during transitions, when they exceed the
+ * size of the squeezer.
+ *
+ * For example, 0.5 means the child will be centered, 0 means it will keep the
+ * start side aligned and overflow the end side, and 1 means the opposite.
+ *
  * Since: 1.0
  */
 void
@@ -1821,6 +1833,12 @@ adw_squeezer_get_yalign (AdwSqueezer *self)
  *
  * Sets the vertical alignment, from 0 (top) to 1 (bottom).
  *
+ * This affects the children allocation during transitions, when they exceed the
+ * size of the squeezer.
+ *
+ * For example, 0.5 means the child will be centered, 0 means it will keep the
+ * top side aligned and overflow the bottom side, and 1 means the opposite.
+ *
  * Since: 1.0
  */
 void
