@@ -187,46 +187,6 @@ page_detached_cb (AdwTabBar  *self,
   g_signal_handlers_disconnect_by_func (page, notify_pinned_cb, self);
 }
 
-static void
-update_needs_attention (AdwTabBar *self,
-                        gboolean   pinned)
-{
-  GtkStyleContext *context;
-  gboolean left, right;
-
-  g_object_get (pinned ? self->pinned_box : self->box,
-                "needs-attention-left", &left,
-                "needs-attention-right", &right,
-                NULL);
-
-  if (pinned)
-    context = gtk_widget_get_style_context (GTK_WIDGET (self->pinned_scrolled_window));
-  else
-    context = gtk_widget_get_style_context (GTK_WIDGET (self->scrolled_window));
-
-  if (left)
-    gtk_style_context_add_class (context, "needs-attention-left");
-  else
-    gtk_style_context_remove_class (context, "needs-attention-left");
-
-  if (right)
-    gtk_style_context_add_class (context, "needs-attention-right");
-  else
-    gtk_style_context_remove_class (context, "needs-attention-right");
-}
-
-static void
-notify_needs_attention_cb (AdwTabBar *self)
-{
-  update_needs_attention (self, FALSE);
-}
-
-static void
-notify_needs_attention_pinned_cb (AdwTabBar *self)
-{
-  update_needs_attention (self, TRUE);
-}
-
 static inline gboolean
 is_overflowing (GtkAdjustment *adj)
 {
@@ -451,11 +411,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_VIEW] =
-    g_param_spec_object ("view",
-                         "View",
-                         "The tab view the tab bar controls.",
+    g_param_spec_object ("view", NULL, NULL,
                          ADW_TYPE_TAB_VIEW,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwTabBar:start-action-widget: (attributes org.gtk.Property.get=adw_tab_bar_get_start_action_widget org.gtk.Property.set=adw_tab_bar_set_start_action_widget)
@@ -465,11 +423,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_START_ACTION_WIDGET] =
-    g_param_spec_object ("start-action-widget",
-                         "Start action widget",
-                         "The widget shown before the tabs",
+    g_param_spec_object ("start-action-widget", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwTabBar:end-action-widget: (attributes org.gtk.Property.get=adw_tab_bar_get_end_action_widget org.gtk.Property.set=adw_tab_bar_set_end_action_widget)
@@ -479,11 +435,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_END_ACTION_WIDGET] =
-    g_param_spec_object ("end-action-widget",
-                         "End action widget",
-                         "The widget shown after the tabs",
+    g_param_spec_object ("end-action-widget", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwTabBar:autohide: (attributes org.gtk.Property.get=adw_tab_bar_get_autohide org.gtk.Property.set=adw_tab_bar_set_autohide)
@@ -498,11 +452,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_AUTOHIDE] =
-    g_param_spec_boolean ("autohide",
-                          "Autohide",
-                          "Whether the tabs automatically hide",
+    g_param_spec_boolean ("autohide", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwTabBar:tabs-revealed: (attributes org.gtk.Property.get=adw_tab_bar_get_tabs_revealed)
@@ -514,11 +466,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_TABS_REVEALED] =
-    g_param_spec_boolean ("tabs-revealed",
-                          "Tabs revealed",
-                          "Whether the tabs are currently revealed",
+    g_param_spec_boolean ("tabs-revealed", NULL, NULL,
                           FALSE,
-                          G_PARAM_READABLE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwTabBar:expand-tabs: (attributes org.gtk.Property.get=adw_tab_bar_get_expand_tabs org.gtk.Property.set=adw_tab_bar_set_expand_tabs)
@@ -531,11 +481,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_EXPAND_TABS] =
-    g_param_spec_boolean ("expand-tabs",
-                          "Expand tabs",
-                          "Whether tabs expand to full width",
+    g_param_spec_boolean ("expand-tabs", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwTabBar:inverted: (attributes org.gtk.Property.get=adw_tab_bar_get_inverted org.gtk.Property.set=adw_tab_bar_set_inverted)
@@ -548,11 +496,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_INVERTED] =
-    g_param_spec_boolean ("inverted",
-                          "Inverted",
-                          "Whether tabs use inverted layout",
+    g_param_spec_boolean ("inverted", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwTabBar:is-overflowing: (attributes org.gtk.Property.get=adw_tab_bar_get_is_overflowing)
@@ -564,11 +510,9 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
    * Since: 1.0
    */
   props[PROP_IS_OVERFLOWING] =
-    g_param_spec_boolean ("is-overflowing",
-                          "Is overflowing",
-                          "Whether the tab bar is overflowing",
+    g_param_spec_boolean ("is-overflowing", NULL, NULL,
                           FALSE,
-                          G_PARAM_READABLE);
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -609,8 +553,6 @@ adw_tab_bar_class_init (AdwTabBarClass *klass)
   gtk_widget_class_bind_template_child (widget_class, AdwTabBar, pinned_scrolled_window);
   gtk_widget_class_bind_template_child (widget_class, AdwTabBar, start_action_bin);
   gtk_widget_class_bind_template_child (widget_class, AdwTabBar, end_action_bin);
-  gtk_widget_class_bind_template_callback (widget_class, notify_needs_attention_cb);
-  gtk_widget_class_bind_template_callback (widget_class, notify_needs_attention_pinned_cb);
   gtk_widget_class_bind_template_callback (widget_class, notify_resize_frozen_cb);
   gtk_widget_class_bind_template_callback (widget_class, stop_kinetic_scrolling_cb);
   gtk_widget_class_bind_template_callback (widget_class, extra_drag_drop_cb);
@@ -631,12 +573,10 @@ adw_tab_bar_init (AdwTabBar *self)
   gtk_widget_init_template (GTK_WIDGET (self));
 
   adj = gtk_scrolled_window_get_hadjustment (self->scrolled_window);
-  adw_tab_box_set_adjustment (self->box, adj);
   g_signal_connect_object (adj, "changed", G_CALLBACK (update_is_overflowing),
                            self, G_CONNECT_SWAPPED);
 
   adj = gtk_scrolled_window_get_hadjustment (self->pinned_scrolled_window);
-  adw_tab_box_set_adjustment (self->pinned_box, adj);
   g_signal_connect_object (adj, "changed", G_CALLBACK (update_is_overflowing),
                            self, G_CONNECT_SWAPPED);
 }
@@ -918,6 +858,11 @@ adw_tab_bar_get_autohide (AdwTabBar *self)
  *
  * Sets whether the tabs automatically hide.
  *
+ * If set to `TRUE`, the tab bar disappears when [property@TabBar:view] has 0
+ * or 1 tab, no pinned tabs, and no tab is being transferred.
+ *
+ * See [property@TabBar:tabs-revealed].
+ *
  * Since: 1.0
  */
 void
@@ -944,6 +889,8 @@ adw_tab_bar_set_autohide (AdwTabBar *self,
  *
  * Gets whether the tabs are currently revealed.
  *
+ * See [property@TabBar:autohide].
+ *
  * Returns: whether the tabs are currently revealed
  *
  * Since: 1.0
@@ -981,6 +928,9 @@ adw_tab_bar_get_expand_tabs (AdwTabBar *self)
  *
  * Sets whether tabs expand to full width.
  *
+ * If set to `TRUE`, the tabs will always vary width filling the whole width
+ * when possible, otherwise tabs will always have the minimum possible size.
+ *
  * Since: 1.0
  */
 void
@@ -1024,6 +974,9 @@ adw_tab_bar_get_inverted (AdwTabBar *self)
  *
  * Sets whether tabs tabs use inverted layout.
  *
+ * If set to `TRUE`, non-pinned tabs will have the close button at the beginning
+ * and the indicator at the end rather than the opposite.
+ *
  * Since: 1.0
  */
 void
@@ -1083,6 +1036,8 @@ adw_tab_bar_setup_extra_drop_target (AdwTabBar     *self,
  *
  * Gets whether @self is overflowing.
  *
+ * If `TRUE`, all tabs cannot be displayed at once and require scrolling.
+ *
  * Returns: whether @self is overflowing
  *
  * Since: 1.0
@@ -1094,3 +1049,19 @@ adw_tab_bar_get_is_overflowing (AdwTabBar *self)
 
   return self->is_overflowing;
 }
+
+AdwTabBox *
+adw_tab_bar_get_tab_box (AdwTabBar *self)
+{
+  g_return_val_if_fail (ADW_IS_TAB_BAR (self), NULL);
+
+  return self->box;
+}
+
+AdwTabBox *
+adw_tab_bar_get_pinned_tab_box (AdwTabBar *self)
+{
+  g_return_val_if_fail (ADW_IS_TAB_BAR (self), NULL);
+
+  return self->pinned_box;
+}
