@@ -117,11 +117,11 @@ enum {
   PAGE_PROP_CHILD,
   PAGE_PROP_NAME,
   PAGE_PROP_TITLE,
+  PAGE_PROP_USE_UNDERLINE,
   PAGE_PROP_ICON_NAME,
   PAGE_PROP_NEEDS_ATTENTION,
   PAGE_PROP_BADGE_NUMBER,
   PAGE_PROP_VISIBLE,
-  PAGE_PROP_USE_UNDERLINE,
   LAST_PAGE_PROP
 };
 
@@ -166,6 +166,9 @@ adw_view_stack_page_get_property (GObject      *object,
   case PAGE_PROP_TITLE:
     g_value_set_string (value, adw_view_stack_page_get_title (self));
     break;
+  case PAGE_PROP_USE_UNDERLINE:
+    g_value_set_boolean (value, adw_view_stack_page_get_use_underline (self));
+    break;
   case PAGE_PROP_ICON_NAME:
     g_value_set_string (value, adw_view_stack_page_get_icon_name (self));
     break;
@@ -178,9 +181,6 @@ adw_view_stack_page_get_property (GObject      *object,
   case PAGE_PROP_VISIBLE:
     g_value_set_boolean (value, adw_view_stack_page_get_visible (self));
     break;
-  case PAGE_PROP_USE_UNDERLINE:
-    g_value_set_boolean (value, adw_view_stack_page_get_use_underline (self));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     break;
@@ -205,6 +205,9 @@ adw_view_stack_page_set_property (GObject      *object,
   case PAGE_PROP_TITLE:
     adw_view_stack_page_set_title (self, g_value_get_string (value));
     break;
+  case PAGE_PROP_USE_UNDERLINE:
+    adw_view_stack_page_set_use_underline (self, g_value_get_boolean (value));
+    break;
   case PAGE_PROP_ICON_NAME:
     adw_view_stack_page_set_icon_name (self, g_value_get_string (value));
     break;
@@ -217,9 +220,6 @@ adw_view_stack_page_set_property (GObject      *object,
   case PAGE_PROP_VISIBLE:
     adw_view_stack_page_set_visible (self, g_value_get_boolean (value));
     break;
-  case PAGE_PROP_USE_UNDERLINE:
-    adw_view_stack_page_set_use_underline (self, g_value_get_boolean (value));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     break;
@@ -255,16 +255,14 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
   /**
    * AdwViewStackPage:child: (attributes org.gtk.Property.get=adw_view_stack_page_get_child)
    *
-   * The child of the page.
+   * The stack child to which the page belongs.
    *
    * Since: 1.0
    */
   page_props[PAGE_PROP_CHILD] =
-    g_param_spec_object ("child",
-                         "Child",
-                         "The child of the page",
+    g_param_spec_object ("child", NULL, NULL,
                          GTK_TYPE_WIDGET,
-                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
   /**
    * AdwViewStackPage:name: (attributes org.gtk.Property.get=adw_view_stack_page_get_name org.gtk.Property.set=adw_view_stack_page_set_name)
@@ -274,11 +272,9 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
    * Since: 1.0
    */
   page_props[PAGE_PROP_NAME] =
-    g_param_spec_string ("name",
-                         "Name",
-                         "The name of the child page",
+    g_param_spec_string ("name", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStackPage:title: (attributes org.gtk.Property.get=adw_view_stack_page_get_title org.gtk.Property.set=adw_view_stack_page_set_title)
@@ -288,11 +284,21 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
    * Since: 1.0
    */
   page_props[PAGE_PROP_TITLE] =
-    g_param_spec_string ("title",
-                         "Title",
-                         "The title of the child page",
+    g_param_spec_string ("title", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
+
+  /**
+   * AdwViewStackPage:use-underline: (attributes org.gtk.Property.get=adw_view_stack_page_get_use_underline org.gtk.Property.set=adw_view_stack_page_set_use_underline)
+   *
+   * Whether an embedded underline in the title indicates a mnemonic.
+   *
+   * Since: 1.0
+   */
+  page_props[PAGE_PROP_USE_UNDERLINE] =
+    g_param_spec_boolean ("use-underline", NULL, NULL,
+                          FALSE,
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStackPage:icon-name: (attributes org.gtk.Property.get=adw_view_stack_page_get_icon_name org.gtk.Property.set=adw_view_stack_page_set_icon_name)
@@ -302,11 +308,9 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
    * Since: 1.0
    */
   page_props[PAGE_PROP_ICON_NAME] =
-    g_param_spec_string ("icon-name",
-                         "Icon name",
-                         "The icon name of the child page",
+    g_param_spec_string ("icon-name", NULL, NULL,
                          NULL,
-                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStackPage:needs-attention: (attributes org.gtk.Property.get=adw_view_stack_page_get_needs_attention org.gtk.Property.set=adw_view_stack_page_set_needs_attention)
@@ -318,16 +322,14 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
    * Since: 1.0
    */
   page_props[PAGE_PROP_NEEDS_ATTENTION] =
-    g_param_spec_boolean ("needs-attention",
-                          "Needs Attention",
-                          "Whether the page requires the user attention",
+    g_param_spec_boolean ("needs-attention", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStackPage:badge-number: (attributes org.gtk.Property.get=adw_view_stack_page_get_badge_number org.gtk.Property.set=adw_view_stack_page_set_badge_number)
    *
-   * A number associated with the page.
+   * The badge number for this page.
    *
    * [class@ViewSwitcher] can display it as a badge next to the page icon. It is
    * commonly used to display a number of unread items within the page.
@@ -337,11 +339,9 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
    * Since: 1.0
    */
   page_props[PAGE_PROP_BADGE_NUMBER] =
-    g_param_spec_uint ("badge-number",
-                       "Badge_number",
-                       "A number associated with the page",
+    g_param_spec_uint ("badge-number", NULL, NULL,
                        0, G_MAXUINT, 0,
-                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStackPage:visible: (attributes org.gtk.Property.get=adw_view_stack_page_get_visible org.gtk.Property.set=adw_view_stack_page_set_visible)
@@ -354,25 +354,9 @@ adw_view_stack_page_class_init (AdwViewStackPageClass *class)
    * Since: 1.0
    */
   page_props[PAGE_PROP_VISIBLE] =
-    g_param_spec_boolean ("visible",
-                          "Visible",
-                          "Whether this page is visible",
+    g_param_spec_boolean ("visible", NULL, NULL,
                           TRUE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * AdwViewStackPage:use-underline: (attributes org.gtk.Property.get=adw_view_stack_page_get_use_underline org.gtk.Property.set=adw_view_stack_page_set_use_underline)
-   *
-   * Whether an embedded underline in the title indicates a mnemonic.
-   *
-   * Since: 1.0
-   */
-  page_props[PAGE_PROP_USE_UNDERLINE] =
-    g_param_spec_boolean ("use-underline",
-                          "Use underline",
-                          "Whether an embedded underline in the title label indicates a mnemonic",
-                          FALSE,
-                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PAGE_PROP, page_props);
 }
@@ -699,7 +683,8 @@ static AdwViewStackPage *
 add_internal (AdwViewStack *self,
               GtkWidget    *child,
               const char   *name,
-              const char   *title)
+              const char   *title,
+              const char   *icon_name)
 {
   AdwViewStackPage *page;
 
@@ -709,7 +694,7 @@ add_internal (AdwViewStack *self,
   page->widget = g_object_ref (child);
   page->name = g_strdup (name);
   page->title = g_strdup (title);
-  page->icon_name = NULL;
+  page->icon_name = g_strdup (icon_name);
   page->needs_attention = FALSE;
   page->last_focus = NULL;
 
@@ -913,7 +898,10 @@ adw_view_stack_class_init (AdwViewStackClass *klass)
   /**
    * AdwViewStack:hhomogeneous: (attributes org.gtk.Property.get=adw_view_stack_get_hhomogeneous org.gtk.Property.set=adw_view_stack_set_hhomogeneous)
    *
-   * Whether the stack allocates the same width for all children.
+   * Whether the stack is horizontally homogeneous.
+   *
+   * If the stack is horizontally homogeneous, it allocates the same width for
+   * all children.
    *
    * If it's `FALSE`, the stack may change width when a different child becomes
    * visible.
@@ -921,16 +909,17 @@ adw_view_stack_class_init (AdwViewStackClass *klass)
    * Since: 1.0
    */
   props[PROP_HHOMOGENEOUS] =
-      g_param_spec_boolean ("hhomogeneous",
-                            "Horizontally homogeneous",
-                            "Whether the stack allocates the same width for all children",
-                            TRUE,
-                            G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_boolean ("hhomogeneous", NULL, NULL,
+                          TRUE,
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStack:vhomogeneous: (attributes org.gtk.Property.get=adw_view_stack_get_vhomogeneous org.gtk.Property.set=adw_view_stack_set_vhomogeneous)
    *
-   * Whether the stack allocates the same height for all children.
+   * Whether the stack is vertically homogeneous.
+   *
+   * If the stack is vertically homogeneous, it allocates the same height for
+   * all children.
    *
    * If it's `FALSE`, the stack may change height when a different child becomes
    * visible.
@@ -938,11 +927,9 @@ adw_view_stack_class_init (AdwViewStackClass *klass)
    * Since: 1.0
    */
   props[PROP_VHOMOGENEOUS] =
-      g_param_spec_boolean ("vhomogeneous",
-                            "Vertically homogeneous",
-                            "Whether the stack allocates the same height for all children",
-                            TRUE,
-                            G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_boolean ("vhomogeneous", NULL, NULL,
+                          TRUE,
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStack:visible-child: (attributes org.gtk.Property.get=adw_view_stack_get_visible_child org.gtk.Property.set=adw_view_stack_set_visible_child)
@@ -952,11 +939,9 @@ adw_view_stack_class_init (AdwViewStackClass *klass)
    * Since: 1.0
    */
   props[PROP_VISIBLE_CHILD] =
-      g_param_spec_object ("visible-child",
-                           "Visible child",
-                           "The widget currently visible in the stack",
-                           GTK_TYPE_WIDGET,
-                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_object ("visible-child", NULL, NULL,
+                         GTK_TYPE_WIDGET,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStack:visible-child-name: (attributes org.gtk.Property.get=adw_view_stack_get_visible_child_name org.gtk.Property.set=adw_view_stack_set_visible_child_name)
@@ -968,11 +953,9 @@ adw_view_stack_class_init (AdwViewStackClass *klass)
    * Since: 1.0
    */
   props[PROP_VISIBLE_CHILD_NAME] =
-      g_param_spec_string ("visible-child-name",
-                           "Name of visible child",
-                           "The name of the widget currently visible in the stack",
-                           NULL,
-                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_string ("visible-child-name", NULL, NULL,
+                         NULL,
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewStack:pages: (attributes org.gtk.Property.get=adw_view_stack_get_pages)
@@ -984,11 +967,9 @@ adw_view_stack_class_init (AdwViewStackClass *klass)
    * page.
    */
   props[PROP_PAGES] =
-      g_param_spec_object ("pages",
-                           "Pages",
-                           "A selection model with the stack's pages",
-                           GTK_TYPE_SELECTION_MODEL,
-                           G_PARAM_READABLE);
+    g_param_spec_object ("pages", NULL, NULL,
+                         GTK_TYPE_SELECTION_MODEL,
+                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
@@ -1014,7 +995,7 @@ adw_view_stack_buildable_add_child (GtkBuildable *buildable,
   if (ADW_IS_VIEW_STACK_PAGE (child))
     add_page (self, ADW_VIEW_STACK_PAGE (child));
   else if (GTK_IS_WIDGET (child))
-    add_internal (self, GTK_WIDGET (child), NULL, NULL);
+    add_internal (self, GTK_WIDGET (child), NULL, NULL, NULL);
   else
     parent_buildable_iface->add_child (buildable, builder, child, type);
 }
@@ -1045,178 +1026,6 @@ adw_view_stack_page_get_child (AdwViewStackPage *self)
   return self->widget;
 }
 
-/**
- * adw_view_stack_page_get_visible: (attributes org.gtk.Method.get_property=visible)
- * @self: a view stack page
- *
- * Gets whether @self is visible in its `AdwViewStack`.
- *
- * This is independent from the [property@Gtk.Widget:visible]
- * property of its widget.
- *
- * Returns: whether @self is visible
- *
- * Since: 1.0
- */
-gboolean
-adw_view_stack_page_get_visible (AdwViewStackPage *self)
-{
-  g_return_val_if_fail (ADW_IS_VIEW_STACK_PAGE (self), FALSE);
-
-  return self->visible;
-}
-
-/**
- * adw_view_stack_page_set_visible: (attributes org.gtk.Method.set_property=visible)
- * @self: a view stack page
- * @visible: whether @self is visible
- *
- * Sets whether @page is visible in its `AdwViewStack`.
- *
- * Since: 1.0
- */
-void
-adw_view_stack_page_set_visible (AdwViewStackPage *self,
-                                 gboolean          visible)
-{
-  g_return_if_fail (ADW_IS_VIEW_STACK_PAGE (self));
-
-  visible = !!visible;
-
-  if (visible == self->visible)
-    return;
-
-  self->visible = visible;
-
-  if (self->widget && gtk_widget_get_parent (self->widget))
-    update_child_visible (ADW_VIEW_STACK (gtk_widget_get_parent (self->widget)), self);
-
-  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_VISIBLE]);
-}
-
-/**
- * adw_view_stack_page_get_needs_attention: (attributes org.gtk.Method.get_property=needs-attention)
- * @self: a view stack page
- *
- * Gets whether the page is marked as “needs attention”.
- *
- * Returns: whether the page needs attention
- *
- * Since: 1.0
- */
-gboolean
-adw_view_stack_page_get_needs_attention (AdwViewStackPage *self)
-{
-  g_return_val_if_fail (ADW_IS_VIEW_STACK_PAGE (self), FALSE);
-
-  return self->needs_attention;
-}
-
-/**
- * adw_view_stack_page_set_needs_attention: (attributes org.gtk.Method.set_property=needs-attention)
- * @self: a view stack page
- * @needs_attention: the new value to set
- *
- * Sets whether the page is marked as “needs attention”.
- *
- * Since: 1.0
- */
-void
-adw_view_stack_page_set_needs_attention (AdwViewStackPage *self,
-                                         gboolean          needs_attention)
-{
-  g_return_if_fail (ADW_IS_VIEW_STACK_PAGE (self));
-
-  needs_attention = !!needs_attention;
-
-  if (needs_attention == self->needs_attention)
-    return;
-
-  self->needs_attention = needs_attention;
-
-  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_NEEDS_ATTENTION]);
-}
-
-/**
- * adw_view_stack_page_get_badge_number: (attributes org.gtk.Method.get_property=badge-number)
- * @self: a view stack page
- *
- * Gets the badge number for this page.
- *
- * Returns: the badge number for this page
- *
- * Since: 1.0
- */
-guint
-adw_view_stack_page_get_badge_number (AdwViewStackPage *self)
-{
-  g_return_val_if_fail (ADW_IS_VIEW_STACK_PAGE (self), 0);
-
-  return self->badge_number;
-}
-
-/**
- * adw_view_stack_page_set_badge_number: (attributes org.gtk.Method.set_property=badge-number)
- * @self: a view stack page
- * @badge_number: the new value to set
- *
- * Sets the badge number for this page.
- *
- * Since: 1.0
- */
-void
-adw_view_stack_page_set_badge_number (AdwViewStackPage *self,
-                                      guint             badge_number)
-{
-  g_return_if_fail (ADW_IS_VIEW_STACK_PAGE (self));
-
-  if (badge_number == self->badge_number)
-    return;
-
-  self->badge_number = badge_number;
-
-  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_BADGE_NUMBER]);
-}
-
-/**
- * adw_view_stack_page_get_use_underline: (attributes org.gtk.Method.get_property=use-underline)
- * @self: a view stack page
- *
- * Gets whether underlines in the page title indicate mnemonics.
- *
- * Returns: whether underlines in the page title indicate mnemonics
- *
- * Since: 1.0
- */
-gboolean
-adw_view_stack_page_get_use_underline (AdwViewStackPage *self)
-{
-  return self->use_underline;
-}
-
-/**
- * adw_view_stack_page_set_use_underline: (attributes org.gtk.Method.set_property=use-underline)
- * @self: a view stack page
- * @use_underline: the new value to set
- *
- * Sets whether underlines in the page title indicate mnemonics.
- *
- * Since: 1.0
- */
-void
-adw_view_stack_page_set_use_underline (AdwViewStackPage *self,
-                                       gboolean          use_underline)
-{
-  use_underline = !!use_underline;
-
-  if (use_underline == self->use_underline)
-    return;
-
-  self->use_underline = use_underline;
-
-  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_USE_UNDERLINE]);
-}
-
 /**
  * adw_view_stack_page_get_name: (attributes org.gtk.Method.get_property=name)
  * @self: a view stack page
@@ -1327,6 +1136,45 @@ adw_view_stack_page_set_title (AdwViewStackPage *self,
   g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_TITLE]);
 }
 
+/**
+ * adw_view_stack_page_get_use_underline: (attributes org.gtk.Method.get_property=use-underline)
+ * @self: a view stack page
+ *
+ * Gets whether underlines in the page title indicate mnemonics.
+ *
+ * Returns: whether underlines in the page title indicate mnemonics
+ *
+ * Since: 1.0
+ */
+gboolean
+adw_view_stack_page_get_use_underline (AdwViewStackPage *self)
+{
+  return self->use_underline;
+}
+
+/**
+ * adw_view_stack_page_set_use_underline: (attributes org.gtk.Method.set_property=use-underline)
+ * @self: a view stack page
+ * @use_underline: the new value to set
+ *
+ * Sets whether underlines in the page title indicate mnemonics.
+ *
+ * Since: 1.0
+ */
+void
+adw_view_stack_page_set_use_underline (AdwViewStackPage *self,
+                                       gboolean          use_underline)
+{
+  use_underline = !!use_underline;
+
+  if (use_underline == self->use_underline)
+    return;
+
+  self->use_underline = use_underline;
+
+  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_USE_UNDERLINE]);
+}
+
 /**
  * adw_view_stack_page_get_icon_name: (attributes org.gtk.Method.get_property=icon-name)
  * @self: a view stack page
@@ -1369,6 +1217,149 @@ adw_view_stack_page_set_icon_name (AdwViewStackPage *self,
   g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_ICON_NAME]);
 }
 
+/**
+ * adw_view_stack_page_get_needs_attention: (attributes org.gtk.Method.get_property=needs-attention)
+ * @self: a view stack page
+ *
+ * Gets whether the page requires the user attention.
+ *
+ * Returns: whether the page needs attention
+ *
+ * Since: 1.0
+ */
+gboolean
+adw_view_stack_page_get_needs_attention (AdwViewStackPage *self)
+{
+  g_return_val_if_fail (ADW_IS_VIEW_STACK_PAGE (self), FALSE);
+
+  return self->needs_attention;
+}
+
+/**
+ * adw_view_stack_page_set_needs_attention: (attributes org.gtk.Method.set_property=needs-attention)
+ * @self: a view stack page
+ * @needs_attention: the new value to set
+ *
+ * Sets whether the page requires the user attention.
+ *
+ * [class@ViewSwitcher] will display it as a dot next to the page icon.
+ *
+ * Since: 1.0
+ */
+void
+adw_view_stack_page_set_needs_attention (AdwViewStackPage *self,
+                                         gboolean          needs_attention)
+{
+  g_return_if_fail (ADW_IS_VIEW_STACK_PAGE (self));
+
+  needs_attention = !!needs_attention;
+
+  if (needs_attention == self->needs_attention)
+    return;
+
+  self->needs_attention = needs_attention;
+
+  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_NEEDS_ATTENTION]);
+}
+
+/**
+ * adw_view_stack_page_get_badge_number: (attributes org.gtk.Method.get_property=badge-number)
+ * @self: a view stack page
+ *
+ * Gets the badge number for this page.
+ *
+ * Returns: the badge number for this page
+ *
+ * Since: 1.0
+ */
+guint
+adw_view_stack_page_get_badge_number (AdwViewStackPage *self)
+{
+  g_return_val_if_fail (ADW_IS_VIEW_STACK_PAGE (self), 0);
+
+  return self->badge_number;
+}
+
+/**
+ * adw_view_stack_page_set_badge_number: (attributes org.gtk.Method.set_property=badge-number)
+ * @self: a view stack page
+ * @badge_number: the new value to set
+ *
+ * Sets the badge number for this page.
+ *
+ * [class@ViewSwitcher] can display it as a badge next to the page icon. It is
+ * commonly used to display a number of unread items within the page.
+ *
+ * It can be used together with [property@ViewStack{age}:needs-attention].
+ *
+ * Since: 1.0
+ */
+void
+adw_view_stack_page_set_badge_number (AdwViewStackPage *self,
+                                      guint             badge_number)
+{
+  g_return_if_fail (ADW_IS_VIEW_STACK_PAGE (self));
+
+  if (badge_number == self->badge_number)
+    return;
+
+  self->badge_number = badge_number;
+
+  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_BADGE_NUMBER]);
+}
+
+/**
+ * adw_view_stack_page_get_visible: (attributes org.gtk.Method.get_property=visible)
+ * @self: a view stack page
+ *
+ * Gets whether @self is visible in its `AdwViewStack`.
+ *
+ * This is independent from the [property@Gtk.Widget:visible]
+ * property of its widget.
+ *
+ * Returns: whether @self is visible
+ *
+ * Since: 1.0
+ */
+gboolean
+adw_view_stack_page_get_visible (AdwViewStackPage *self)
+{
+  g_return_val_if_fail (ADW_IS_VIEW_STACK_PAGE (self), FALSE);
+
+  return self->visible;
+}
+
+/**
+ * adw_view_stack_page_set_visible: (attributes org.gtk.Method.set_property=visible)
+ * @self: a view stack page
+ * @visible: whether @self is visible
+ *
+ * Sets whether @page is visible in its `AdwViewStack`.
+ *
+ * This is independent from the [property@Gtk.Widget:visible] property of
+ * [property@ViewStackPage:child].
+ *
+ * Since: 1.0
+ */
+void
+adw_view_stack_page_set_visible (AdwViewStackPage *self,
+                                 gboolean          visible)
+{
+  g_return_if_fail (ADW_IS_VIEW_STACK_PAGE (self));
+
+  visible = !!visible;
+
+  if (visible == self->visible)
+    return;
+
+  self->visible = visible;
+
+  if (self->widget && gtk_widget_get_parent (self->widget))
+    update_child_visible (ADW_VIEW_STACK (gtk_widget_get_parent (self->widget)), self);
+
+  g_object_notify_by_pspec (G_OBJECT (self), page_props[PAGE_PROP_VISIBLE]);
+}
+
 /**
  * adw_view_stack_new:
  *
@@ -1402,7 +1393,7 @@ adw_view_stack_add (AdwViewStack   *self,
   g_return_val_if_fail (ADW_IS_VIEW_STACK (self), NULL);
   g_return_val_if_fail (GTK_IS_WIDGET (child), NULL);
 
-  return add_internal (self, child, NULL, NULL);
+  return add_internal (self, child, NULL, NULL, NULL);
 }
 
 /**
@@ -1427,7 +1418,7 @@ adw_view_stack_add_named (AdwViewStack   *self,
   g_return_val_if_fail (ADW_IS_VIEW_STACK (self), NULL);
   g_return_val_if_fail (GTK_IS_WIDGET (child), NULL);
 
-  return add_internal (self, child, name, NULL);
+  return add_internal (self, child, name, NULL, NULL);
 }
 
 /**
@@ -1455,7 +1446,37 @@ adw_view_stack_add_titled (AdwViewStack   *self,
   g_return_val_if_fail (ADW_IS_VIEW_STACK (self), NULL);
   g_return_val_if_fail (GTK_IS_WIDGET (child), NULL);
 
-  return add_internal (self, child, name, title);
+  return add_internal (self, child, name, title, NULL);
+}
+
+/**
+ * adw_view_stack_add_titled_with_icon:
+ * @self: a view stack
+ * @child: the widget to add
+ * @name: (nullable): the name for @child
+ * @title: a human-readable title for @child
+ * @icon_name: an icon name for @child
+ *
+ * Adds a child to @self.
+ *
+ * The child is identified by the @name. The @title and @icon_name will be used
+ * by [class@ViewSwitcher] to represent @child.
+ *
+ * Returns: (transfer none): the `AdwViewStackPage` for @child
+ *
+ * Since: 1.2
+ */
+AdwViewStackPage *
+adw_view_stack_add_titled_with_icon (AdwViewStack *self,
+                                     GtkWidget    *child,
+                                     const char   *name,
+                                     const char   *title,
+                                     const char   *icon_name)
+{
+  g_return_val_if_fail (ADW_IS_VIEW_STACK (self), NULL);
+  g_return_val_if_fail (GTK_IS_WIDGET (child), NULL);
+
+  return add_internal (self, child, name, title, icon_name);
 }
 
 /**
@@ -1610,6 +1631,8 @@ adw_view_stack_get_visible_child_name (AdwViewStack *self)
  *
  * Makes the child with @name visible.
  *
+ * See [property@ViewStack:visible-child].
+ *
  * Since: 1.0
  */
 void
@@ -1635,6 +1658,24 @@ adw_view_stack_set_visible_child_name (AdwViewStack *self,
     set_visible_child (self, page);
 }
 
+/**
+ * adw_view_stack_get_hhomogeneous: (attributes org.gtk.Method.get_property=hhomogeneous)
+ * @self: a view stack
+ *
+ * Gets whether @self is horizontally homogeneous.
+ *
+ * Returns: whether @self is horizontally homogeneous
+ *
+ * Since: 1.0
+ */
+gboolean
+adw_view_stack_get_hhomogeneous (AdwViewStack *self)
+{
+  g_return_val_if_fail (ADW_IS_VIEW_STACK (self), FALSE);
+
+  return self->homogeneous[GTK_ORIENTATION_HORIZONTAL];
+}
+
 /**
  * adw_view_stack_set_hhomogeneous: (attributes org.gtk.Method.set_property=hhomogeneous)
  * @self: a view stack
@@ -1642,6 +1683,12 @@ adw_view_stack_set_visible_child_name (AdwViewStack *self,
  *
  * Sets @self to be horizontally homogeneous or not.
  *
+ * If the stack is horizontally homogeneous, it allocates the same width for
+ * all children.
+ *
+ * If it's `FALSE`, the stack may change width when a different child becomes
+ * visible.
+ *
  * Since: 1.0
  */
 void
@@ -1664,21 +1711,21 @@ adw_view_stack_set_hhomogeneous (AdwViewStack *self,
 }
 
 /**
- * adw_view_stack_get_hhomogeneous: (attributes org.gtk.Method.get_property=hhomogeneous)
+ * adw_view_stack_get_vhomogeneous: (attributes org.gtk.Method.get_property=vhomogeneous)
  * @self: a view stack
  *
- * Gets whether @self is horizontally homogeneous.
+ * Gets whether @self is vertically homogeneous.
  *
- * Returns: whether @self is horizontally homogeneous
+ * Returns: whether @self is vertically homogeneous
  *
  * Since: 1.0
  */
 gboolean
-adw_view_stack_get_hhomogeneous (AdwViewStack *self)
+adw_view_stack_get_vhomogeneous (AdwViewStack *self)
 {
   g_return_val_if_fail (ADW_IS_VIEW_STACK (self), FALSE);
 
-  return self->homogeneous[GTK_ORIENTATION_HORIZONTAL];
+  return self->homogeneous[GTK_ORIENTATION_VERTICAL];
 }
 
 /**
@@ -1688,6 +1735,12 @@ adw_view_stack_get_hhomogeneous (AdwViewStack *self)
  *
  * Sets @self to be vertically homogeneous or not.
  *
+ * If the stack is vertically homogeneous, it allocates the same height for
+ * all children.
+ *
+ * If it's `FALSE`, the stack may change height when a different child becomes
+ * visible.
+ *
  * Since: 1.0
  */
 void
@@ -1709,24 +1762,6 @@ adw_view_stack_set_vhomogeneous (AdwViewStack *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_VHOMOGENEOUS]);
 }
 
-/**
- * adw_view_stack_get_vhomogeneous: (attributes org.gtk.Method.get_property=vhomogeneous)
- * @self: a view stack
- *
- * Gets whether @self is vertically homogeneous.
- *
- * Returns: whether @self is vertically homogeneous
- *
- * Since: 1.0
- */
-gboolean
-adw_view_stack_get_vhomogeneous (AdwViewStack *self)
-{
-  g_return_val_if_fail (ADW_IS_VIEW_STACK (self), FALSE);
-
-  return self->homogeneous[GTK_ORIENTATION_VERTICAL];
-}
-
 /**
  * adw_view_stack_get_pages: (attributes org.gtk.Method.get_property=pages)
  * @self: a view stack
