@@ -36,17 +36,17 @@
  *
  * ```xml
  * <object class="GtkWindow">
- *   <child type="titlebar">
+ *   <property name="titlebar">
  *     <object class="AdwHeaderBar">
  *       <property name="centering-policy">strict</property>
- *       <child type="title">
+ *       <property name="title-widget">
  *         <object class="AdwViewSwitcherTitle" id="title">
  *           <property name="stack">stack</property>
  *         </object>
- *       </child>
+ *       </property>
  *     </object>
- *   </child>
- *   <child>
+ *   </property>
+ *   <property name="child">
  *     <object class="GtkBox">
  *       <property name="orientation">vertical</property>
  *       <child>
@@ -61,7 +61,7 @@
  *         </object>
  *       </child>
  *     </object>
- *   </child>
+ *   </property>
  * </object>
  * ```
  *
@@ -166,13 +166,8 @@ adw_view_switcher_bar_dispose (GObject *object)
 {
   AdwViewSwitcherBar *self = ADW_VIEW_SWITCHER_BAR (object);
 
-  if (self->pages) {
-    g_signal_handlers_disconnect_by_func (self->pages, G_CALLBACK (update_bar_revealed), self);
-    g_clear_object (&self->pages);
-  }
-
+  adw_view_switcher_bar_set_stack (self, NULL);
   gtk_widget_unparent (self->action_bar);
-  self->view_switcher = NULL;
 
   G_OBJECT_CLASS (adw_view_switcher_bar_parent_class)->dispose (object);
 }
@@ -195,11 +190,9 @@ adw_view_switcher_bar_class_init (AdwViewSwitcherBarClass *klass)
    * Since: 1.0
    */
   props[PROP_STACK] =
-    g_param_spec_object ("stack",
-                         "Stack",
-                         "The stack the view switcher controls",
+    g_param_spec_object ("stack", NULL, NULL,
                          ADW_TYPE_VIEW_STACK,
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
    * AdwViewSwitcherBar:reveal: (attributes org.gtk.Property.get=adw_view_switcher_bar_get_reveal org.gtk.Property.set=adw_view_switcher_bar_set_reveal)
@@ -209,11 +202,9 @@ adw_view_switcher_bar_class_init (AdwViewSwitcherBarClass *klass)
    * Since: 1.0
    */
   props[PROP_REVEAL] =
-    g_param_spec_boolean ("reveal",
-                         "Reveal",
-                         "Whether the bar should be revealed or hidden",
+    g_param_spec_boolean ("reveal", NULL, NULL,
                          FALSE,
-                         G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
