@@ -215,6 +215,41 @@ test_adw_tab_view_menu_model (void)
   g_assert_finalize_object (model2);
 }
 
+static void
+test_adw_tab_view_shortcuts (void)
+{
+  AdwTabView *view = g_object_ref_sink (ADW_TAB_VIEW (adw_tab_view_new ()));
+  AdwTabViewShortcuts shortcuts;
+
+  g_assert_nonnull (view);
+
+  notified = 0;
+  g_signal_connect (view, "notify::shortcuts", G_CALLBACK (notify_cb), NULL);
+
+  g_object_get (view, "shortcuts", &shortcuts, NULL);
+  g_assert_cmpint (shortcuts, ==, ADW_TAB_VIEW_SHORTCUT_ALL_SHORTCUTS);
+  g_assert_cmpint (notified, ==, 0);
+
+  adw_tab_view_set_shortcuts (view, ADW_TAB_VIEW_SHORTCUT_CONTROL_PAGE_UP);
+  g_assert_cmpint (adw_tab_view_get_shortcuts (view), ==, ADW_TAB_VIEW_SHORTCUT_CONTROL_PAGE_UP);
+  g_assert_cmpint (notified, ==, 1);
+
+  g_object_set (view, "shortcuts", ADW_TAB_VIEW_SHORTCUT_CONTROL_PAGE_DOWN, NULL);
+  g_assert_cmpint (adw_tab_view_get_shortcuts (view), ==, ADW_TAB_VIEW_SHORTCUT_CONTROL_PAGE_DOWN);
+  g_assert_cmpint (notified, ==, 2);
+
+  adw_tab_view_add_shortcuts (view, ADW_TAB_VIEW_SHORTCUT_CONTROL_HOME);
+  g_assert_cmpint (adw_tab_view_get_shortcuts (view), ==, ADW_TAB_VIEW_SHORTCUT_CONTROL_PAGE_DOWN |
+                                                          ADW_TAB_VIEW_SHORTCUT_CONTROL_HOME);
+  g_assert_cmpint (notified, ==, 3);
+
+  adw_tab_view_remove_shortcuts (view, ADW_TAB_VIEW_SHORTCUT_CONTROL_PAGE_DOWN);
+  g_assert_cmpint (adw_tab_view_get_shortcuts (view), ==, ADW_TAB_VIEW_SHORTCUT_CONTROL_HOME);
+  g_assert_cmpint (notified, ==, 4);
+
+  g_assert_finalize_object (view);
+}
+
 static void
 test_adw_tab_view_get_page (void)
 {
@@ -1089,6 +1124,37 @@ test_adw_tab_page_indicator_icon (void)
   g_assert_finalize_object (icon2);
 }
 
+static void
+test_adw_tab_page_indicator_tooltip (void)
+{
+  AdwTabView *view = g_object_ref_sink (ADW_TAB_VIEW (adw_tab_view_new ()));
+  AdwTabPage *page;
+  char *tooltip;
+
+  g_assert_nonnull (view);
+
+  page = adw_tab_view_append (view, gtk_button_new ());
+  g_assert_nonnull (page);
+
+  notified = 0;
+  g_signal_connect (page, "notify::indicator-tooltip", G_CALLBACK (notify_cb), NULL);
+
+  g_object_get (page, "indicator-tooltip", &tooltip, NULL);
+  g_assert_cmpstr (tooltip, ==, "");
+  g_assert_cmpint (notified, ==, 0);
+
+  adw_tab_page_set_indicator_tooltip (page, "Some tooltip");
+  g_assert_cmpstr (adw_tab_page_get_indicator_tooltip (page), ==, "Some tooltip");
+  g_assert_cmpint (notified, ==, 1);
+
+  g_object_set (page, "indicator-tooltip", "Some other tooltip", NULL);
+  g_assert_cmpstr (adw_tab_page_get_indicator_tooltip (page), ==, "Some other tooltip");
+  g_assert_cmpint (notified, ==, 2);
+
+  g_free (tooltip);
+  g_assert_finalize_object (view);
+}
+
 static void
 test_adw_tab_page_indicator_activatable (void)
 {
@@ -1230,6 +1296,7 @@ main (int   argc,
   g_test_add_func ("/Adwaita/TabView/n_pinned_pages", test_adw_tab_view_n_pinned_pages);
   g_test_add_func ("/Adwaita/TabView/default_icon", test_adw_tab_view_default_icon);
   g_test_add_func ("/Adwaita/TabView/menu_model", test_adw_tab_view_menu_model);
+  g_test_add_func ("/Adwaita/TabView/shortcuts", test_adw_tab_view_shortcuts);
   g_test_add_func ("/Adwaita/TabView/get_page", test_adw_tab_view_get_page);
   g_test_add_func ("/Adwaita/TabView/select", test_adw_tab_view_select);
   g_test_add_func ("/Adwaita/TabView/add_basic", test_adw_tab_view_add_basic);
@@ -1251,6 +1318,7 @@ main (int   argc,
   g_test_add_func ("/Adwaita/TabPage/icon", test_adw_tab_page_icon);
   g_test_add_func ("/Adwaita/TabPage/loading", test_adw_tab_page_loading);
   g_test_add_func ("/Adwaita/TabPage/indicator_icon", test_adw_tab_page_indicator_icon);
+  g_test_add_func ("/Adwaita/TabPage/indicator_tooltip", test_adw_tab_page_indicator_tooltip);
   g_test_add_func ("/Adwaita/TabPage/indicator_activatable", test_adw_tab_page_indicator_activatable);
   g_test_add_func ("/Adwaita/TabPage/needs_attention", test_adw_tab_page_needs_attention);
 
